@@ -26,6 +26,8 @@
 
 #include <QDialog>
 
+#include <QMessageBox>
+
 class Export: public QDialog{
 	Q_OBJECT
 
@@ -35,28 +37,30 @@ public:
 
 	static void exportCSV();
 private:
+	static bool okToWrite(const QString& file, QMessageBox::StandardButton& msgBoxButton);
+
 	static bool checkSetSeparator(const QString& str, const QString setSeparator);
 	static QString protectCSV(const QString& str);
 
-	static bool isActivityNotManualyEdited(const int activityIndex, bool& diffTeachers, bool& diffSubject, bool& diffActivityTags, bool& diffStudents, bool& diffCompNStud, bool& diffNStud);
+	static bool isActivityNotManualyEdited(const int activityIndex, bool& diffTeachers, bool& diffSubject, bool& diffActivityTags, bool& diffStudents, bool& diffCompNStud, bool& diffNStud, bool& diffActive);
 
 	static bool selectSeparatorAndTextquote(QString& textquote, QString& fieldSeparator, bool& head);
 
-	static bool exportCSVActivities(QString& lastWarnings, const QString textquote, const QString fieldSeparator, const bool head);
-	static bool exportCSVActivityTags(QString& lastWarnings, const QString textquote, const bool head);
-	static bool exportCSVRoomsAndBuildings(QString& lastWarnings, const QString textquote, const QString fieldSeparator, const bool head);
-	static bool exportCSVSubjects(QString& lastWarnings, const QString textquote, const bool head);
-	static bool exportCSVTeachers(QString& lastWarnings, const QString textquote, const bool head, const QString setSeparator);
-	static bool exportCSVStudents(QString& lastWarnings, const QString textquote, const QString fieldSeparator, const bool head, const QString setSeparator);
-	static bool exportCSVTimetable(QString& lastWarnings, const QString textquote, const QString fieldSeparator, const bool head);
+	static bool exportCSVActivities(QString& lastWarnings, const QString textquote, const QString fieldSeparator, const bool head, QMessageBox::StandardButton& msgBoxButton);
+	static bool exportCSVActivityTags(QString& lastWarnings, const QString textquote, const bool head, const QString setSeparator, QMessageBox::StandardButton& msgBoxButton);
+	static bool exportCSVRoomsAndBuildings(QString& lastWarnings, const QString textquote, const QString fieldSeparator, const bool head, QMessageBox::StandardButton& msgBoxButton);
+	static bool exportCSVSubjects(QString& lastWarnings, const QString textquote, const bool head, QMessageBox::StandardButton& msgBoxButton);
+	static bool exportCSVTeachers(QString& lastWarnings, const QString textquote, const bool head, const QString setSeparator, QMessageBox::StandardButton& msgBoxButton);
+	static bool exportCSVStudents(QString& lastWarnings, const QString textquote, const QString fieldSeparator, const bool head, const QString setSeparator, QMessageBox::StandardButton& msgBoxButton);
+	static bool exportCSVTimetable(QString& lastWarnings, const QString textquote, const QString fieldSeparator, const bool head, QMessageBox::StandardButton& msgBoxButton);
 
 	static bool exportSchILD(QString& lastWarnings);
 };
 
-class lastWarningsDialogE: public QDialog{
+class LastWarningsDialogE: public QDialog{
         Q_OBJECT
 public:							//can i do that privat too?
-	lastWarningsDialogE(QString lastWarning, QWidget *parent = 0);
+	LastWarningsDialogE(QString lastWarning, QWidget *parent = 0);
 };
 
 #endif
