@@ -18,21 +18,37 @@
 #ifndef ACTIVITIESFORM_H
 #define ACTIVITIESFORM_H
 
-#include "activitiesform_template.h"
+#include "ui_activitiesform_template.h"
 
-class ActivitiesForm : public ActivitiesForm_template  {
+#include "activity.h"
+
+#include <QSet>
+#include <QString>
+
+class ActivitiesForm : public QDialog, Ui::ActivitiesForm_template{
+	Q_OBJECT
+	
+private:
+	QSet<QString> showedStudents;
+	
 public:
 	ActivitiesList visibleActivitiesList;
 
 	ActivitiesForm();
 	~ActivitiesForm();
 
+	bool filterOk(Activity* act);
+
+public slots:
 	void addActivity();
 	void removeActivity();
 	void modifyActivity();
-	void activityChanged(int index);
+	void activityChanged();
 	void filterChanged();
-	bool filterOk(Activity* act);
+	
+	void studentsFilterChanged();
+	
+	void help();
 };
 
 #endif
