@@ -18,40 +18,49 @@
 #ifndef ADDCONSTRAINTACTIVITIESNOTOVERLAPPINGFORM_H
 #define ADDCONSTRAINTACTIVITIESNOTOVERLAPPINGFORM_H
 
-#include "addconstraintactivitiesnotoverlappingform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "ui_addconstraintactivitiesnotoverlappingform_template.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
-#include <qlistbox.h>
+#include <q3combobox.h>
+#include <q3listbox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qvaluelist.h>
+#include <q3textedit.h>
 
-class AddConstraintActivitiesNotOverlappingForm : public AddConstraintActivitiesNotOverlappingForm_template  {
+#include <QList>
+
+class AddConstraintActivitiesNotOverlappingForm : public QDialog, Ui::AddConstraintActivitiesNotOverlappingForm_template  {
+	Q_OBJECT
 public:
 	AddConstraintActivitiesNotOverlappingForm();
 	~AddConstraintActivitiesNotOverlappingForm();
 
 	void updateActivitiesListBox();
 	
+	bool filterOk(Activity* a);
+
+public slots:
 	void addActivity();
 	void removeActivity();
 
 	void addConstraint();
 	
+	void filterChanged();
+	
+	void clear();
+	
 private:
 	//the id's of the activities listed in the activities list
-	QValueList<int> activitiesList;
+	QList<int> activitiesList;
 	//the id-s of the activities listed in the list of non-overlapping activities
-	QValueList<int> notOverlappingActivitiesList;
+	QList<int> notOverlappingActivitiesList;
 };
 
 #endif
