@@ -18,30 +18,39 @@
 #ifndef ADDCONSTRAINTACTIVITIESSAMESTARTINGHOURFORM_H
 #define ADDCONSTRAINTACTIVITIESSAMESTARTINGHOURFORM_H
 
-#include "addconstraintactivitiessamestartinghourform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "ui_addconstraintactivitiessamestartinghourform_template.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
-#include <qlistbox.h>
+#include <q3combobox.h>
+#include <q3listbox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qvaluelist.h>
+#include <q3textedit.h>
 
-class AddConstraintActivitiesSameStartingHourForm : public AddConstraintActivitiesSameStartingHourForm_template  {
+#include <QList>
+
+class AddConstraintActivitiesSameStartingHourForm : public QDialog, Ui::AddConstraintActivitiesSameStartingHourForm_template  {
+	Q_OBJECT
 public:
 	AddConstraintActivitiesSameStartingHourForm();
 	~AddConstraintActivitiesSameStartingHourForm();
 
 	void updateActivitiesListBox();
 	
+	bool filterOk(Activity* a);
+
+public slots:
+	void clear();
+
+	void filterChanged();	
+
 	void addActivity();
 	void removeActivity();
 
@@ -49,9 +58,9 @@ public:
 	
 private:
 	//the id's of the activities listed in the activities list
-	QValueList<int> activitiesList;
+	QList<int> activitiesList;
 	//the id-s of the activities listed in the list of same starting hour activities
-	QValueList<int> selectedActivitiesList;
+	QList<int> selectedActivitiesList;
 };
 
 #endif
