@@ -18,7 +18,7 @@
 #ifndef ADDCONSTRAINTACTIVITYPREFERREDROOMSFORM_H
 #define ADDCONSTRAINTACTIVITYPREFERREDROOMSFORM_H
 
-#include "addconstraintactivitypreferredroomsform_template.h"
+#include "ui_addconstraintactivitypreferredroomsform_template.h"
 #include "timetable_defs.h"
 #include "timetable.h"
 #include "fet.h"
@@ -35,7 +35,8 @@
 #include <q3textedit.h>
 #include <q3valuelist.h>
 
-class AddConstraintActivityPreferredRoomsForm : public AddConstraintActivityPreferredRoomsForm_template  {
+class AddConstraintActivityPreferredRoomsForm : public QDialog, Ui::AddConstraintActivityPreferredRoomsForm_template  {
+	Q_OBJECT
 public:
 	AddConstraintActivityPreferredRoomsForm();
 	~AddConstraintActivityPreferredRoomsForm();
@@ -43,14 +44,18 @@ public:
 	void updateRoomsListBox();
 	void updateActivitiesComboBox();	
 	
+	bool filterOk(Activity* a);
+
+public slots:
 	void addRoom();
 	void removeRoom();
 
 	void addConstraint();
 
-	bool filterOk(Activity* a);
 	void filterChanged();
 	
+	void clear();
+	
 private:
 	//the id's of the activities listed in the activities combo
 	QList<int> activitiesList;
