@@ -15,6 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "longtextmessagebox.h"
+
 #include "addconstraintstudentssetmingapsbetweenbuildingchangesform.h"
 #include "spaceconstraint.h"
 
@@ -26,6 +28,14 @@
 
 AddConstraintStudentsSetMinGapsBetweenBuildingChangesForm::AddConstraintStudentsSetMinGapsBetweenBuildingChangesForm()
 {
+    setupUi(this);
+
+//    connect(weightLineEdit, SIGNAL(textChanged(QString)), this /*AddConstraintStudentsSetMinGapsBetweenBuildingChangesForm_template*/, SLOT(constraintChanged()));
+    connect(addConstraintPushButton, SIGNAL(clicked()), this /*AddConstraintStudentsSetMinGapsBetweenBuildingChangesForm_template*/, SLOT(addCurrentConstraint()));
+    connect(closePushButton, SIGNAL(clicked()), this /*AddConstraintStudentsSetMinGapsBetweenBuildingChangesForm_template*/, SLOT(close()));
+//    connect(studentsComboBox, SIGNAL(activated(QString)), this /*AddConstraintStudentsSetMinGapsBetweenBuildingChangesForm_template*/, SLOT(constraintChanged()));
+//    connect(minGapsSpinBox, SIGNAL(valueChanged(int)), this /*AddConstraintStudentsSetMinGapsBetweenBuildingChangesForm_template*/, SLOT(constraintChanged()));
+
 	//setWindowFlags(Qt::Window);
 	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
@@ -33,6 +43,9 @@ AddConstraintStudentsSetMinGapsBetweenBuildingChangesForm::AddConstraintStudents
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
 	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+
+	QSize tmp2=studentsComboBox->minimumSizeHint();
+	Q_UNUSED(tmp2);
 		
 	minGapsSpinBox->setMinValue(1);
 	minGapsSpinBox->setMaxValue(gt.rules.nHoursPerDay);
@@ -65,26 +78,26 @@ void AddConstraintStudentsSetMinGapsBetweenBuildingChangesForm::updateStudentsSe
 }
 
 void AddConstraintStudentsSetMinGapsBetweenBuildingChangesForm::constraintChanged()
-{
+{/*
 	QString s;
-	s+=QObject::tr("Current constraint:");
+	s+=tr("Current constraint:");
 	s+="\n";
 
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	s+=QObject::tr("Weight (percentage)=%1").arg(weight);
+	s+=tr("Weight (percentage)=%1").arg(weight);
 	s+="\n";
 
-	s+=QObject::tr("Students set min gaps between building changes");
+	s+=tr("Students set min gaps between building changes");
 	s+="\n";
-	s+=QObject::tr("Students set=%1").arg(studentsComboBox->currentText());
+	s+=tr("Students set=%1").arg(studentsComboBox->currentText());
 	s+="\n";
 	
-	s+=QObject::tr("Max building changes per day=%1").arg(minGapsSpinBox->value());
+	s+=tr("Max building changes per day=%1").arg(minGapsSpinBox->value());
 	s+="\n";
 
-	currentConstraintTextEdit->setText(s);
+	currentConstraintTextEdit->setText(s);*/
 }
 
 void AddConstraintStudentsSetMinGapsBetweenBuildingChangesForm::addCurrentConstraint()
@@ -95,16 +108,16 @@ void AddConstraintStudentsSetMinGapsBetweenBuildingChangesForm::addCurrentConstr
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
 	if(weight<100.0 || weight>100.0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid weight (percentage). It has to be 100"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid weight (percentage). It has to be 100"));
 		return;
 	}
 
 	QString students_name=studentsComboBox->currentText();
 	StudentsSet* s=gt.rules.searchStudentsSet(students_name);
 	if(s==NULL){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid students set"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid students set"));
 		return;
 	}
 
@@ -112,11 +125,11 @@ void AddConstraintStudentsSetMinGapsBetweenBuildingChangesForm::addCurrentConstr
 
 	bool tmp2=gt.rules.addSpaceConstraint(ctr);
 	if(tmp2)
-		QMessageBox::information(this, QObject::tr("FET information"),
-			QObject::tr("Constraint added"));
+		LongTextMessageBox::information(this, tr("FET information"),
+			tr("Constraint added:")+"\n\n"+ctr->getDetailedDescription(gt.rules));
 	else{
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Constraint NOT added - please report error"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Constraint NOT added - please report error"));
 		delete ctr;
 	}
 }
