@@ -15,6 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "longtextmessagebox.h"
+
 #include "addconstraintsubjectactivitytagpreferredroomform.h"
 #include "spaceconstraint.h"
 
@@ -27,6 +29,12 @@
 
 AddConstraintSubjectActivityTagPreferredRoomForm::AddConstraintSubjectActivityTagPreferredRoomForm()
 {
+    setupUi(this);
+
+    connect(closePushButton, SIGNAL(clicked()), this /*AddConstraintSubjectActivityTagPreferredRoomForm_template*/, SLOT(close()));
+    connect(addConstraintPushButton, SIGNAL(clicked()), this /*AddConstraintSubjectActivityTagPreferredRoomForm_template*/, SLOT(addConstraint()));
+
+
 	//setWindowFlags(Qt::Window);
 	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
@@ -34,6 +42,14 @@ AddConstraintSubjectActivityTagPreferredRoomForm::AddConstraintSubjectActivityTa
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
 	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+
+	QSize tmp3=subjectsComboBox->minimumSizeHint();
+	Q_UNUSED(tmp3);
+	QSize tmp4=activityTagsComboBox->minimumSizeHint();
+	Q_UNUSED(tmp4);
+	
+	QSize tmp5=roomsComboBox->minimumSizeHint();
+	Q_UNUSED(tmp5);
 	
 	updateSubjectsComboBox();
 	updateActivityTagsComboBox();
@@ -79,8 +95,8 @@ void AddConstraintSubjectActivityTagPreferredRoomForm::addConstraint()
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
 	if(weight<0.0 || weight>100){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid weight"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid weight"));
 		return;
 	}
 
@@ -90,24 +106,24 @@ void AddConstraintSubjectActivityTagPreferredRoomForm::addConstraint()
 
 	int i=subjectsComboBox->currentItem();
 	if(i<0 || subjectsComboBox->count()<=0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid subject"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid subject"));
 		return;
 	}
 	QString subject=subjectsComboBox->currentText();
 
 	i=activityTagsComboBox->currentItem();
 	if(i<0 || activityTagsComboBox->count()<=0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid activity tag"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid activity tag"));
 		return;
 	}
 	QString activityTag=activityTagsComboBox->currentText();
 
 	i=roomsComboBox->currentItem();
 	if(i<0 || roomsComboBox->count()<=0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid room"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid room"));
 		return;
 	}
 	QString room=roomsComboBox->currentText();
@@ -116,14 +132,14 @@ void AddConstraintSubjectActivityTagPreferredRoomForm::addConstraint()
 
 	bool tmp2=gt.rules.addSpaceConstraint(ctr);
 	if(tmp2){
-		QString s=QObject::tr("Constraint added:");
-		s+="\n";
+		QString s=tr("Constraint added:");
+		s+="\n\n";
 		s+=ctr->getDetailedDescription(gt.rules);
-		QMessageBox::information(this, QObject::tr("FET information"), s);
+		LongTextMessageBox::information(this, tr("FET information"), s);
 	}
 	else{
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Constraint NOT added - error ?"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Constraint NOT added - error ?"));
 		delete ctr;
 	}
 }
