@@ -18,36 +18,59 @@
 #ifndef ALLSPACECONSTRAINTSFORM_H
 #define ALLSPACECONSTRAINTSFORM_H
 
-#include "allspaceconstraintsform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "ui_allspaceconstraintsform_template.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
 
-#include <qcombobox.h>
+#include "advancedfilterform.h"
+
+#include <q3combobox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qlistbox.h>
+#include <q3textedit.h>
+#include <q3listbox.h>
 
-class AllSpaceConstraintsForm : public AllSpaceConstraintsForm_template  {
+/*
+typedef enum {ALL, ANY} ALLANY;
+typedef enum {DESCRIPTION=0, DETDESCRIPTION=1} DESCRDETDESCR;
+typedef enum {CONTAINS=0, DOESNOTCONTAIN=1, REGEXP=2, NOTREGEXP=3} CONTAINSORNOT;*/
+
+class AllSpaceConstraintsForm : public QDialog, Ui::AllSpaceConstraintsForm_template  {
+	Q_OBJECT
+
+private:
+	AdvancedFilterForm* filterForm;
+
+	QList<SpaceConstraint*> visibleSpaceConstraintsList;
+	
+	static bool filterInitialized;
+
+	static bool all; //all or any, true means all, false means any
+	static QList<int> descrDetDescr;
+	static QList<int> contains;
+	static QStringList text;
+	static bool caseSensitive;
+	
+	bool useFilter;
+	
 public:
-	SpaceConstraintsList visibleConstraintsList;
-
 	AllSpaceConstraintsForm();
 	~AllSpaceConstraintsForm();
 
-	void constraintChanged(int index);
-	void modifyConstraint();
-	void removeConstraint();
+	bool filterOk(SpaceConstraint* ctr);
 	
 	void filterChanged();
-
-	bool filterOk(SpaceConstraint* ctr);
+	
+public slots:
+	void constraintChanged();
+	void modifyConstraint();
+	void removeConstraint();
+	void filter(bool active);
 };
 
 #endif
