@@ -15,6 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "longtextmessagebox.h"
+
 #include "constraintstudentsearlymaxbeginningsatsecondhourform.h"
 #include "addconstraintstudentsearlymaxbeginningsatsecondhourform.h"
 #include "modifyconstraintstudentsearlymaxbeginningsatsecondhourform.h"
@@ -23,6 +25,16 @@
 
 ConstraintStudentsEarlyMaxBeginningsAtSecondHourForm::ConstraintStudentsEarlyMaxBeginningsAtSecondHourForm()
 {
+    setupUi(this);
+
+    connect(constraintsListBox, SIGNAL(highlighted(int)), this /*ConstraintStudentsEarlyMaxBeginningsAtSecondHourForm_template*/, SLOT(constraintChanged(int)));
+    connect(addConstraintPushButton, SIGNAL(clicked()), this /*ConstraintStudentsEarlyMaxBeginningsAtSecondHourForm_template*/, SLOT(addConstraint()));
+    connect(closePushButton, SIGNAL(clicked()), this /*ConstraintStudentsEarlyMaxBeginningsAtSecondHourForm_template*/, SLOT(close()));
+    connect(removeConstraintPushButton, SIGNAL(clicked()), this /*ConstraintStudentsEarlyMaxBeginningsAtSecondHourForm_template*/, SLOT(removeConstraint()));
+    connect(modifyConstraintPushButton, SIGNAL(clicked()), this /*ConstraintStudentsEarlyMaxBeginningsAtSecondHourForm_template*/, SLOT(modifyConstraint()));
+    connect(constraintsListBox, SIGNAL(selected(QString)), this /*ConstraintStudentsEarlyMaxBeginningsAtSecondHourForm_template*/, SLOT(modifyConstraint()));
+
+
 	//setWindowFlags(Qt::Window);
 	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
@@ -71,8 +83,8 @@ void ConstraintStudentsEarlyMaxBeginningsAtSecondHourForm::constraintChanged(int
 
 void ConstraintStudentsEarlyMaxBeginningsAtSecondHourForm::addConstraint()
 {
-	AddConstraintStudentsEarlyMaxBeginningsAtSecondHourForm *form=new AddConstraintStudentsEarlyMaxBeginningsAtSecondHourForm();
-	form->exec();
+	AddConstraintStudentsEarlyMaxBeginningsAtSecondHourForm form;
+	form.exec();
 
 	filterChanged();
 	
@@ -88,8 +100,8 @@ void ConstraintStudentsEarlyMaxBeginningsAtSecondHourForm::modifyConstraint()
 	}
 	TimeConstraint* ctr=this->visibleConstraintsList.at(i);
 
-	ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm *form = new ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm((ConstraintStudentsEarlyMaxBeginningsAtSecondHour*)ctr);
-	form->exec();
+	ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm form((ConstraintStudentsEarlyMaxBeginningsAtSecondHour*)ctr);
+	form.exec();
 
 	filterChanged();
 	constraintsListBox->setCurrentItem(i);
@@ -104,12 +116,13 @@ void ConstraintStudentsEarlyMaxBeginningsAtSecondHourForm::removeConstraint()
 	}
 	TimeConstraint* ctr=this->visibleConstraintsList.at(i);
 	QString s;
-	s=tr("Removing constraint:\n");
+	s=tr("Remove constraint?");
+	s+="\n\n";
 	s+=ctr->getDetailedDescription(gt.rules);
-	s+=tr("\nAre you sure?");
+	//s+=tr("\nAre you sure?");
 
-	switch( QMessageBox::warning( this, tr("FET warning"),
-		s, tr("OK"), tr("Cancel"), 0, 0, 1 ) ){
+	switch( LongTextMessageBox::confirmation( this, tr("FET confirmation"),
+		s, tr("Yes"), tr("No"), 0, 0, 1 ) ){
 	case 0: // The user clicked the OK again button or pressed Enter
 		gt.rules.removeTimeConstraint(ctr);
 		filterChanged();
