@@ -18,7 +18,7 @@
 #ifndef CONSTRAINTSUBJECTPREFERREDROOMSFORM_H
 #define CONSTRAINTSUBJECTPREFERREDROOMSFORM_H
 
-#include "constraintsubjectpreferredroomsform_template.h"
+#include "ui_constraintsubjectpreferredroomsform_template.h"
 #include "timetable_defs.h"
 #include "timetable.h"
 #include "fet.h"
@@ -34,22 +34,24 @@
 #include <q3textedit.h>
 #include <q3listbox.h>
 
-class ConstraintSubjectPreferredRoomsForm : public ConstraintSubjectPreferredRoomsForm_template  {
+class ConstraintSubjectPreferredRoomsForm : public QDialog, Ui::ConstraintSubjectPreferredRoomsForm_template  {
+	Q_OBJECT
 public:
 	SpaceConstraintsList visibleConstraintsList;
 
 	ConstraintSubjectPreferredRoomsForm();
 	~ConstraintSubjectPreferredRoomsForm();
 
+	void refreshConstraintsListBox();
+
+	bool filterOk(SpaceConstraint* ctr);
+	
+public slots:
 	void constraintChanged(int index);
 	void addConstraint();
 	void removeConstraint();
 	void modifyConstraint();
 	
-	void refreshConstraintsListBox();
-
-	bool filterOk(SpaceConstraint* ctr);
-	
 	void filterChanged();
 };
 
