@@ -34,6 +34,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 using namespace std;
 
 
+class FetTranslate: public QObject{
+	Q_OBJECT
+};
+
 /**
 The one and only instantiation of the main class.
 */
