@@ -13,18 +13,22 @@
 #ifndef GROUPSFORM_H
 #define GROUPSFORM_H
 
-#include "groupsform_template.h"
+#include "ui_groupsform_template.h"
 
-class GroupsForm : public GroupsForm_template
+class GroupsForm : public QDialog, Ui::GroupsForm_template
 {
+	Q_OBJECT
 public:
 	GroupsForm();
 	~GroupsForm();
 
+public slots:
 	void addGroup();
 	void removeGroup();
 	void modifyGroup();
+	
 	void sortGroups();
+	
 	void yearChanged(const QString &yearName);
 	void groupChanged(const QString &groupName);
 	
