@@ -3,7 +3,7 @@
                              -------------------
     begin                : Feb 20, 2005
     copyright            : (C) 2005 by Lalescu Liviu
-    email                : liviu@lalescu.ro
+    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,10 +18,12 @@
 #ifndef HELPFAQFORM_H
 #define HELPFAQFORM_H
 
-#include "helpfaqform_template.h"
+#include "ui_helpfaqform_template.h"
 
-class HelpFaqForm : public HelpFaqForm_template
+class HelpFaqForm : public QDialog, Ui::HelpFaqForm_template
 {
+	Q_OBJECT
+	
 public: 
 	HelpFaqForm();
 	~HelpFaqForm();
