@@ -49,6 +49,42 @@
 
 ModifyActivityForm::ModifyActivityForm(int id, int activityGroupId)
 {
+    setupUi(this);
+
+    connect(subjectsComboBox, SIGNAL(activated(QString)), this /*ModifyActivityForm_template*/, SLOT(subjectChanged(QString)));
+    connect(cancelPushButton, SIGNAL(clicked()), this, SLOT(cancel()));
+    connect(okPushButton, SIGNAL(clicked()), this, SLOT(ok()));
+    connect(clearTeacherPushButton, SIGNAL(clicked()), this, SLOT(clearTeachers()));
+    connect(clearStudentsPushButton, SIGNAL(clicked()), this, SLOT(clearStudents()));
+//    connect(nStudentsSpinBox, SIGNAL(valueChanged(int)), this, SLOT(activityChanged()));
+//    connect(active8CheckBox, SIGNAL(toggled(bool)), this, SLOT(activityChanged()));
+//    connect(duration8SpinBox, SIGNAL(valueChanged(int)), this, SLOT(activityChanged()));
+//    connect(active7CheckBox, SIGNAL(toggled(bool)), this, SLOT(activityChanged()));
+//    connect(duration7SpinBox, SIGNAL(valueChanged(int)), this, SLOT(activityChanged()));
+//    connect(active6CheckBox, SIGNAL(toggled(bool)), this, SLOT(activityChanged()));
+//    connect(duration6SpinBox, SIGNAL(valueChanged(int)), this, SLOT(activityChanged()));
+//    connect(active5CheckBox, SIGNAL(toggled(bool)), this, SLOT(activityChanged()));
+//    connect(duration5SpinBox, SIGNAL(valueChanged(int)), this, SLOT(activityChanged()));
+//    connect(active4CheckBox, SIGNAL(toggled(bool)), this, SLOT(activityChanged()));
+//    connect(duration4SpinBox, SIGNAL(valueChanged(int)), this, SLOT(activityChanged()));
+//    connect(active3CheckBox, SIGNAL(toggled(bool)), this, SLOT(activityChanged()));
+//    connect(duration3SpinBox, SIGNAL(valueChanged(int)), this, SLOT(activityChanged()));
+//    connect(active2CheckBox, SIGNAL(toggled(bool)), this, SLOT(activityChanged()));
+//    connect(duration2SpinBox, SIGNAL(valueChanged(int)), this, SLOT(activityChanged()));
+//    connect(active1CheckBox, SIGNAL(toggled(bool)), this, SLOT(activityChanged()));
+//    connect(duration1SpinBox, SIGNAL(valueChanged(int)), this, SLOT(activityChanged()));
+    connect(allTeachersListBox, SIGNAL(selected(QString)), this, SLOT(addTeacher()));
+    connect(selectedTeachersListBox, SIGNAL(selected(QString)), this, SLOT(removeTeacher()));
+    connect(allStudentsListBox, SIGNAL(selected(QString)), this, SLOT(addStudents()));
+    connect(selectedStudentsListBox, SIGNAL(selected(QString)), this, SLOT(removeStudents()));
+    connect(clearActivityTagPushButton, SIGNAL(clicked()), this, SLOT(clearActivityTags()));
+    connect(allActivityTagsListBox, SIGNAL(selected(QString)), this, SLOT(addActivityTag()));
+    connect(selectedActivityTagsListBox, SIGNAL(selected(QString)), this, SLOT(removeActivityTag()));
+    connect(showYearsCheckBox, SIGNAL(toggled(bool)), this, SLOT(showYearsChanged()));
+    connect(showGroupsCheckBox, SIGNAL(toggled(bool)), this, SLOT(showGroupsChanged()));
+    connect(showSubgroupsCheckBox, SIGNAL(toggled(bool)), this, SLOT(showSubgroupsChanged()));
+
+
 	//setWindowFlags(Qt::Window);
 	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
@@ -56,6 +92,9 @@ ModifyActivityForm::ModifyActivityForm(int id, int activityGroupId)
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
 	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+
+	QSize tmp3=subjectsComboBox->minimumSizeHint();
+	Q_UNUSED(tmp3);
 	
 	this->_id=id;
 	this->_activityGroupId=activityGroupId;
@@ -99,6 +138,7 @@ ModifyActivityForm::ModifyActivityForm(int id, int activityGroupId)
 		//par(0)->setChecked(this->_activity->parity==PARITY_FORTNIGHTLY);
 		dur(0)->setValue(this->_activity->duration);
 		activ(0)->setChecked(this->_activity->active);
+		subactivitiesTabWidget->setCurrentPage(0);
 	}
 
 	splitSpinBox->setMinValue(nSplit);
@@ -121,12 +161,19 @@ ModifyActivityForm::ModifyActivityForm(int id, int activityGroupId)
 	updateTeachersListBox();
 	updateSubjectsComboBox();
 	updateActivityTagsListBox();
+	
+	selectedStudentsListBox->clear();
+	for(QStringList::Iterator it=this->_students.begin(); it!=this->_students.end(); it++)
+		selectedStudentsListBox->insertItem(*it);
 
 	for(int i=0; i<10; i++)
 		if(i<nSplit)
 			subTab(i)->setEnabled(true);
 		else
 			subTab(i)->setDisabled(true);
+			
+	okPushButton->setDefault(true);
+	okPushButton->setFocus();
 }
 
 ModifyActivityForm::~ModifyActivityForm()
@@ -166,23 +213,6 @@ void ModifyActivityForm::updateSubjectsComboBox()
 
 void ModifyActivityForm::updateActivityTagsListBox()
 {
-/*	int i=0, j=-1;
-	activityTagsComboBox->clear();
-	activityTagsComboBox->insertItem("");
-	if(this->_activityTag=="")
-		j=i;
-	i++;
-	for(int k=0; k<gt.rules.activityTagsList.size(); k++, i++){
-		ActivityTag* sbt=gt.rules.activityTagsList[k];
-		activityTagsComboBox->insertItem(sbt->name);
-		if(sbt->name==this->_activityTag)
-			j=i;
-	}
-	assert(j!=-1);
-	activityTagsComboBox->setCurrentItem(j);
-
-	activityTagChanged("");*/
-	
 	allActivityTagsListBox->clear();
 	for(int i=0; i<gt.rules.activityTagsList.size(); i++){
 		ActivityTag* at=gt.rules.activityTagsList[i];
@@ -196,25 +226,62 @@ void ModifyActivityForm::updateActivityTagsListBox()
 	activityChanged();
 }
 
+void ModifyActivityForm::showYearsChanged()
+{
+	updateStudentsListBox();
+}
+
+void ModifyActivityForm::showGroupsChanged()
+{
+	updateStudentsListBox();
+}
+
+void ModifyActivityForm::showSubgroupsChanged()
+{
+	updateStudentsListBox();
+}
+
 void ModifyActivityForm::updateStudentsListBox()
 {
+	const int INDENT=2;
+
+	bool showYears=showYearsCheckBox->isChecked();
+	bool showGroups=showGroupsCheckBox->isChecked();
+	bool showSubgroups=showSubgroupsCheckBox->isChecked();
+
 	allStudentsListBox->clear();
+	canonicalStudentsSetsNames.clear();
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
-		allStudentsListBox->insertItem(sty->name);
+		if(showYears){
+			allStudentsListBox->insertItem(sty->name);
+			canonicalStudentsSetsNames.append(sty->name);
+		}
 		for(int j=0; j<sty->groupsList.size(); j++){
 			StudentsGroup* stg=sty->groupsList[j];
-			allStudentsListBox->insertItem(stg->name);
+			if(showGroups){
+				QString begin=QString("");
+				QString end=QString("");
+				begin=QString(INDENT, ' ');
+				if(LANGUAGE_STYLE_RIGHT_TO_LEFT==true)
+					end=QString(INDENT, ' ');
+				allStudentsListBox->insertItem(begin+stg->name+end);
+				canonicalStudentsSetsNames.append(stg->name);
+			}
 			for(int k=0; k<stg->subgroupsList.size(); k++){
 				StudentsSubgroup* sts=stg->subgroupsList[k];
-				allStudentsListBox->insertItem(sts->name);
+				if(showSubgroups){
+					QString begin=QString("");
+					QString end=QString("");
+					begin=QString(2*INDENT, ' ');
+					if(LANGUAGE_STYLE_RIGHT_TO_LEFT==true)
+						end=QString(2*INDENT, ' ');
+					allStudentsListBox->insertItem(begin+sts->name+end);
+					canonicalStudentsSetsNames.append(sts->name);
+				}
 			}
 		}
 	}
-	
-	selectedStudentsListBox->clear();
-	for(QStringList::Iterator it=this->_students.begin(); it!=this->_students.end(); it++)
-		selectedStudentsListBox->insertItem(*it);
 
 	activityChanged();
 }
@@ -274,11 +341,14 @@ void ModifyActivityForm::addStudents()
 	if(allStudentsListBox->currentItem()<0 || (uint)(allStudentsListBox->currentItem())>=allStudentsListBox->count())
 		return;
 	
+	assert(canonicalStudentsSetsNames.count()==(int)(allStudentsListBox->count()));
+	QString sn=canonicalStudentsSetsNames.at(allStudentsListBox->currentItem());
+	
 	for(uint i=0; i<selectedStudentsListBox->count(); i++)
-		if(selectedStudentsListBox->text(i)==allStudentsListBox->currentText())
+		if(selectedStudentsListBox->text(i)==sn)
 			return;
 			
-	selectedStudentsListBox->insertItem(allStudentsListBox->currentText());
+	selectedStudentsListBox->insertItem(sn);
 	
 	activityChanged();
 }
@@ -389,7 +459,7 @@ void ModifyActivityForm::activityChanged()
 
 void ModifyActivityForm::cancel()
 {
-	this->close();
+	this->reject();
 }
 
 void ModifyActivityForm::ok()
@@ -398,19 +468,12 @@ void ModifyActivityForm::ok()
 	QStringList teachers_names;
 	if(selectedTeachersListBox->count()<=0){
 		int t=QMessageBox::question(this, tr("FET question"),
-		 tr("Do you really want to have the activity with no teacher(s)?"),
-		 QMessageBox::Yes, QMessageBox::Cancel);
+		 tr("Do you really want to have the activity without teacher(s)?"),
+		 QMessageBox::Yes|QMessageBox::No, QMessageBox::Yes);
 
-		if(t==QMessageBox::Cancel)
+		if(t==QMessageBox::No)
 			return;
 	}
-	/*else if(selectedTeachersListBox->count()>(uint)(MAX_TEACHERS_PER_ACTIVITY)){
-		QMessageBox::warning(this, tr("FET information"),
-			tr("Too many teachers for an activity. The current maximum is %1.\n"
-			"If you really need more teachers per activity, please talk to the author").
-			arg(MAX_TEACHERS_PER_ACTIVITY));
-		return;
-	}*/
 	else{
 		for(uint i=0; i<selectedTeachersListBox->count(); i++){
 			assert(gt.rules.searchTeacher(selectedTeachersListBox->text(i))>=0);
@@ -429,13 +492,6 @@ void ModifyActivityForm::ok()
 
 	//activity tag
 	QStringList activity_tags_names;
-	/*
-	int activity_tag_index=gt.rules.searchActivityTag(activity_tag_name);
-	if(activity_tag_index<0 && activity_tag_name!=""){
-		QMessageBox::warning(this, tr("FET information"),
-			tr("Invalid activity tag"));
-		return;
-	}*/
 	for(uint i=0; i<selectedActivityTagsListBox->count(); i++){
 		assert(gt.rules.searchActivityTag(selectedActivityTagsListBox->text(i))>=0);
 		activity_tags_names.append(selectedActivityTagsListBox->text(i));
@@ -445,10 +501,10 @@ void ModifyActivityForm::ok()
 	QStringList students_names;
 	if(selectedStudentsListBox->count()<=0){
 		int t=QMessageBox::question(this, tr("FET question"),
-		 tr("Do you really want to have the activity with no student set(s)?"),
-		 QMessageBox::Yes, QMessageBox::Cancel);
+		 tr("Do you really want to have the activity without student set(s)?"),
+		 QMessageBox::Yes|QMessageBox::No, QMessageBox::Yes);
 
-		if(t==QMessageBox::Cancel)
+		if(t==QMessageBox::No)
 			return;
 	}
 	else{
@@ -492,7 +548,7 @@ void ModifyActivityForm::ok()
 		 (nStudentsSpinBox->value()==-1), nStudentsSpinBox->value());
 	}
 	
-	this->close();
+	this->accept();
 }
 
 void ModifyActivityForm::clearTeachers()
@@ -513,8 +569,6 @@ void ModifyActivityForm::clearActivityTags()
 	activityChanged();
 }
 
-//#undef prefDay
-//#undef prefHour
 #undef subTab
 #undef activ
 #undef dur
