@@ -18,42 +18,52 @@
 #ifndef MODIFYCONSTRAINTACTIVITIESNOTOVERLAPPINGFORM_H
 #define MODIFYCONSTRAINTACTIVITIESNOTOVERLAPPINGFORM_H
 
-#include "modifyconstraintactivitiesnotoverlappingform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "ui_modifyconstraintactivitiesnotoverlappingform_template.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
-#include <qlistbox.h>
+#include <q3combobox.h>
+#include <q3listbox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qvaluelist.h>
+#include <q3textedit.h>
 
-class ModifyConstraintActivitiesNotOverlappingForm : public ModifyConstraintActivitiesNotOverlappingForm_template  {
+#include <QList>
+
+class ModifyConstraintActivitiesNotOverlappingForm : public QDialog, Ui::ModifyConstraintActivitiesNotOverlappingForm_template  {
+	Q_OBJECT
 public:
 	ModifyConstraintActivitiesNotOverlappingForm(ConstraintActivitiesNotOverlapping* ctr);
 	~ModifyConstraintActivitiesNotOverlappingForm();
 
-	void updateActivitiesListBox();
+	//void updateActivitiesListBox();
+
+	bool filterOk(Activity* ac);
 	
+	
+public slots:
+	void filterChanged();
+
 	void addActivity();
 	void removeActivity();
 
+	void clear();
+
 	void ok();
 	void cancel();
 	
 private:
 	ConstraintActivitiesNotOverlapping* _ctr;
 	//the id's of the activities listed in the activities list
-	QValueList<int> activitiesList;
+	QList<int> activitiesList;
 	//the id-s of the activities listed in the list of non-overlapping activities
-	QValueList<int> notOverlappingActivitiesList;
+	QList<int> notOverlappingActivitiesList;
 };
 
 #endif
