@@ -18,30 +18,39 @@
 #ifndef MODIFYCONSTRAINTACTIVITIESSAMESTARTINGHOURFORM_H
 #define MODIFYCONSTRAINTACTIVITIESSAMESTARTINGHOURFORM_H
 
-#include "modifyconstraintactivitiessamestartinghourform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "ui_modifyconstraintactivitiessamestartinghourform_template.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
-#include <qlistbox.h>
+#include <q3combobox.h>
+#include <q3listbox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qvaluelist.h>
+#include <q3textedit.h>
 
-class ModifyConstraintActivitiesSameStartingHourForm : public ModifyConstraintActivitiesSameStartingHourForm_template  {
+#include <QList>
+
+class ModifyConstraintActivitiesSameStartingHourForm : public QDialog, Ui::ModifyConstraintActivitiesSameStartingHourForm_template  {
+	Q_OBJECT
 public:
 	ModifyConstraintActivitiesSameStartingHourForm(ConstraintActivitiesSameStartingHour* ctr);
 	~ModifyConstraintActivitiesSameStartingHourForm();
 
 	void updateActivitiesListBox();
 	
+	bool filterOk(Activity* a);
+
+public slots:
+	void filterChanged();
+
+	void clear();
+
 	void addActivity();
 	void removeActivity();
 
@@ -51,9 +60,9 @@ public:
 private:
 	ConstraintActivitiesSameStartingHour* _ctr;
 	//the id's of the activities listed in the activities list
-	QValueList<int> activitiesList;
+	QList<int> activitiesList;
 	//the id-s of the activities listed in the list of selected activities
-	QValueList<int> selectedActivitiesList;
+	QList<int> selectedActivitiesList;
 };
 
 #endif
