@@ -27,6 +27,17 @@
 
 ModifyConstraintActivityPreferredRoomsForm::ModifyConstraintActivityPreferredRoomsForm(ConstraintActivityPreferredRooms* ctr)
 {
+    setupUi(this);
+
+//    connect(addPushButton, SIGNAL(clicked()), this /*ModifyConstraintActivityPreferredRoomsForm_template*/, SLOT(addRoom()));
+//    connect(removePushButton, SIGNAL(clicked()), this /*ModifyConstraintActivityPreferredRoomsForm_template*/, SLOT(removeRoom()));
+    connect(cancelPushButton, SIGNAL(clicked()), this /*ModifyConstraintActivityPreferredRoomsForm_template*/, SLOT(cancel()));
+    connect(okPushButton, SIGNAL(clicked()), this /*ModifyConstraintActivityPreferredRoomsForm_template*/, SLOT(ok()));
+    connect(roomsListBox, SIGNAL(selected(QString)), this /*ModifyConstraintActivityPreferredRoomsForm_template*/, SLOT(addRoom()));
+    connect(selectedRoomsListBox, SIGNAL(selected(QString)), this /*ModifyConstraintActivityPreferredRoomsForm_template*/, SLOT(removeRoom()));
+
+    connect(clearPushButton, SIGNAL(clicked()), this, SLOT(clear()));
+
 	//setWindowFlags(Qt::Window);
 	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
@@ -34,6 +45,11 @@ ModifyConstraintActivityPreferredRoomsForm::ModifyConstraintActivityPreferredRoo
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
 	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+
+	QSize tmp5=activitiesComboBox->minimumSizeHint();
+	Q_UNUSED(tmp5);
+	
+	activitiesComboBox->setMaximumWidth(maxRecommendedWidth(this));
 	
 	updateRoomsListBox();
 
@@ -80,8 +96,8 @@ void ModifyConstraintActivityPreferredRoomsForm::ok()
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
 	if(weight<0.0 || weight>100){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid weight"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid weight"));
 		return;
 	}
 
@@ -90,19 +106,19 @@ void ModifyConstraintActivityPreferredRoomsForm::ok()
 		compulsory=true;*/
 
 	if(selectedRoomsListBox->count()==0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Empty list of selected rooms"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Empty list of selected rooms"));
 		return;
 	}
 	if(selectedRoomsListBox->count()==1){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Only one selected room - please use constraint activity preferred room if you want a single room"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Only one selected room - please use constraint activity preferred room if you want a single room"));
 		return;
 	}
 	
 	if(activitiesComboBox->currentItem()<0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid selected activity"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid selected activity"));
 		return;
 	}
 	int id=gt.rules.activitiesList.at(activitiesComboBox->currentItem())->id;
@@ -148,3 +164,8 @@ void ModifyConstraintActivityPreferredRoomsForm::removeRoom()
 		return;		
 	selectedRoomsListBox->removeItem(selectedRoomsListBox->currentItem());
 }
+
+void ModifyConstraintActivityPreferredRoomsForm::clear()
+{
+	selectedRoomsListBox->clear();
+}
