@@ -18,7 +18,7 @@
 #ifndef MODIFYCONSTRAINTACTIVITYPREFERREDROOMSFORM_H
 #define MODIFYCONSTRAINTACTIVITYPREFERREDROOMSFORM_H
 
-#include "modifyconstraintactivitypreferredroomsform_template.h"
+#include "ui_modifyconstraintactivitypreferredroomsform_template.h"
 #include "timetable_defs.h"
 #include "timetable.h"
 #include "fet.h"
@@ -35,18 +35,22 @@
 #include <q3textedit.h>
 #include <q3valuelist.h>
 
-class ModifyConstraintActivityPreferredRoomsForm : public ModifyConstraintActivityPreferredRoomsForm_template  {
+class ModifyConstraintActivityPreferredRoomsForm : public QDialog, Ui::ModifyConstraintActivityPreferredRoomsForm_template  {
+	Q_OBJECT
 public:
 	ModifyConstraintActivityPreferredRoomsForm(ConstraintActivityPreferredRooms* ctr);
 	~ModifyConstraintActivityPreferredRoomsForm();
 
 	void updateRoomsListBox();
 	
+public slots:
 	void addRoom();
 	void removeRoom();
 
 	void ok();
 	void cancel();
+	
+	void clear();
 private:
 	ConstraintActivityPreferredRooms* _ctr;
 };
