@@ -24,10 +24,16 @@
 
 #include <QDesktopWidget>
 
-//#define yesNo(x)	((x)==0?tr("no"):tr("yes"))
-
 ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm::ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm(ConstraintStudentsEarlyMaxBeginningsAtSecondHour* ctr)
 {
+    setupUi(this);
+
+//    connect(weightLineEdit, SIGNAL(textChanged(QString)), this /*ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm_template*/, SLOT(constraintChanged()));
+    connect(okPushButton, SIGNAL(clicked()), this /*ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm_template*/, SLOT(ok()));
+    connect(cancelPushButton, SIGNAL(clicked()), this /*ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm_template*/, SLOT(cancel()));
+//    connect(maxBeginningsSpinBox, SIGNAL(valueChanged(int)), this /*ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm_template*/, SLOT(constraintChanged()));
+
+
 	//setWindowFlags(Qt::Window);
 	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
@@ -51,7 +57,7 @@ ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm::~ModifyConstraintStu
 }
 
 void ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm::constraintChanged()
-{
+{/*
 	QString s;
 	s+=tr("Current constraint:");
 	s+="\n";
@@ -62,20 +68,11 @@ void ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm::constraintChang
 	s+=tr("Weight (percentage)=%1").arg(weight);
 	s+="\n";
 
-	/*bool compulsory=false;
-	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
-	s+=tr("Compulsory=%1").arg(yesNo(compulsory));
-	s+="\n";*/
-
 	s+=tr("Students must begin activities early, with maximum %1 beginnings at the second available hour, per week (not available and break not counted)")
 	 .arg(maxBeginningsSpinBox->value());
  	s+="\n";
 			
-	/*s+=tr("Students must begin activities as early as possible (permitted by not available and break)");
-	s+="\n";*/
-
-	currentConstraintTextEdit->setText(s);
+	currentConstraintTextEdit->setText(s);*/
 }
 
 void ModifyConstraintStudentsEarlyMaxBeginningsAtSecondHourForm::ok()
