@@ -27,6 +27,17 @@
 
 ModifyConstraintSubjectActivityTagPreferredRoomsForm::ModifyConstraintSubjectActivityTagPreferredRoomsForm(ConstraintSubjectActivityTagPreferredRooms* ctr)
 {
+    setupUi(this);
+
+//    connect(addPushButton, SIGNAL(clicked()), this /*ModifyConstraintSubjectActivityTagPreferredRoomsForm_template*/, SLOT(addRoom()));
+//    connect(removePushButton, SIGNAL(clicked()), this /*ModifyConstraintSubjectActivityTagPreferredRoomsForm_template*/, SLOT(removeRoom()));
+    connect(cancelPushButton, SIGNAL(clicked()), this /*ModifyConstraintSubjectActivityTagPreferredRoomsForm_template*/, SLOT(cancel()));
+    connect(okPushButton, SIGNAL(clicked()), this /*ModifyConstraintSubjectActivityTagPreferredRoomsForm_template*/, SLOT(ok()));
+    connect(roomsListBox, SIGNAL(selected(QString)), this /*ModifyConstraintSubjectActivityTagPreferredRoomsForm_template*/, SLOT(addRoom()));
+    connect(selectedRoomsListBox, SIGNAL(selected(QString)), this /*ModifyConstraintSubjectActivityTagPreferredRoomsForm_template*/, SLOT(removeRoom()));
+
+    connect(clearPushButton, SIGNAL(clicked()), this, SLOT(clear()));
+
 	//setWindowFlags(Qt::Window);
 	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
@@ -34,6 +45,11 @@ ModifyConstraintSubjectActivityTagPreferredRoomsForm::ModifyConstraintSubjectAct
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
 	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+
+	QSize tmp3=subjectsComboBox->minimumSizeHint();
+	Q_UNUSED(tmp3);
+	QSize tmp4=activityTagsComboBox->minimumSizeHint();
+	Q_UNUSED(tmp4);
 	
 	updateRoomsListBox();
 	
@@ -95,8 +111,8 @@ void ModifyConstraintSubjectActivityTagPreferredRoomsForm::ok()
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
 	if(weight<0.0 || weight>100){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid weight"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid weight"));
 		return;
 	}
 
@@ -105,26 +121,26 @@ void ModifyConstraintSubjectActivityTagPreferredRoomsForm::ok()
 		compulsory=true;*/
 
 	if(selectedRoomsListBox->count()==0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Empty list of selected rooms"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Empty list of selected rooms"));
 		return;
 	}
 	if(selectedRoomsListBox->count()==1){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Only one selected room - please use constraint subject preferred room if you want a single room"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Only one selected room - please use constraint subject activity tag preferred room if you want a single room"));
 		return;
 	}
 	
 	if(subjectsComboBox->currentItem()<0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid selected subject"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid selected subject"));
 		return;
 	}
 	QString subject=subjectsComboBox->currentText();
 	
 	if(activityTagsComboBox->currentItem()<0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid selected activity tag"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid selected activity tag"));
 		return;
 	}
 	QString activityTag=activityTagsComboBox->currentText();
@@ -171,3 +187,8 @@ void ModifyConstraintSubjectActivityTagPreferredRoomsForm::removeRoom()
 		return;		
 	selectedRoomsListBox->removeItem(selectedRoomsListBox->currentItem());
 }
+
+void ModifyConstraintSubjectActivityTagPreferredRoomsForm::clear()
+{
+	selectedRoomsListBox->clear();
+}
