@@ -27,6 +27,17 @@
 
 ModifyConstraintSubjectPreferredRoomsForm::ModifyConstraintSubjectPreferredRoomsForm(ConstraintSubjectPreferredRooms* ctr)
 {
+    setupUi(this);
+
+//    connect(addPushButton, SIGNAL(clicked()), this /*ModifyConstraintSubjectPreferredRoomsForm_template*/, SLOT(addRoom()));
+//    connect(removePushButton, SIGNAL(clicked()), this /*ModifyConstraintSubjectPreferredRoomsForm_template*/, SLOT(removeRoom()));
+    connect(cancelPushButton, SIGNAL(clicked()), this /*ModifyConstraintSubjectPreferredRoomsForm_template*/, SLOT(cancel()));
+    connect(okPushButton, SIGNAL(clicked()), this /*ModifyConstraintSubjectPreferredRoomsForm_template*/, SLOT(ok()));
+    connect(roomsListBox, SIGNAL(selected(QString)), this /*ModifyConstraintSubjectPreferredRoomsForm_template*/, SLOT(addRoom()));
+    connect(selectedRoomsListBox, SIGNAL(selected(QString)), this /*ModifyConstraintSubjectPreferredRoomsForm_template*/, SLOT(removeRoom()));
+
+    connect(clearPushButton, SIGNAL(clicked()), this, SLOT(clear()));
+
 	//setWindowFlags(Qt::Window);
 	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
@@ -34,6 +45,9 @@ ModifyConstraintSubjectPreferredRoomsForm::ModifyConstraintSubjectPreferredRooms
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
 	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+
+	QSize tmp3=subjectsComboBox->minimumSizeHint();
+	Q_UNUSED(tmp3);
 	
 	updateRoomsListBox();
 	
@@ -80,8 +94,8 @@ void ModifyConstraintSubjectPreferredRoomsForm::ok()
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
 	if(weight<0.0 || weight>100){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid weight"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid weight"));
 		return;
 	}
 
@@ -90,19 +104,19 @@ void ModifyConstraintSubjectPreferredRoomsForm::ok()
 		compulsory=true;*/
 
 	if(selectedRoomsListBox->count()==0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Empty list of selected rooms"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Empty list of selected rooms"));
 		return;
 	}
 	if(selectedRoomsListBox->count()==1){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Only one selected room - please use constraint subject preferred room if you want a single room"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Only one selected room - please use constraint subject preferred room if you want a single room"));
 		return;
 	}
 	
 	if(subjectsComboBox->currentItem()<0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid selected subject"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid selected subject"));
 		return;
 	}
 	QString subject=subjectsComboBox->currentText();
@@ -148,3 +162,8 @@ void ModifyConstraintSubjectPreferredRoomsForm::removeRoom()
 		return;		
 	selectedRoomsListBox->removeItem(selectedRoomsListBox->currentItem());
 }
+
+void ModifyConstraintSubjectPreferredRoomsForm::clear()
+{
+	selectedRoomsListBox->clear();
+}
