@@ -15,6 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "tablewidgetupdatebug.h"
+
 #include "modifyconstraintteachernotavailabletimesform.h"
 #include "timeconstraint.h"
 
@@ -24,11 +26,29 @@
 
 #include <QDesktopWidget>
 
-#define YES	(QObject::tr("Not available", "Please keep translation short"))
-#define NO	(QObject::tr("Available", "Please keep translation short"))
+#include <QHeaderView>
+#include <QTableWidget>
+#include <QTableWidgetItem>
+
+#include <QBrush>
+#include <QColor>
+
+//#define YES	(ModifyConstraintTeacherNotAvailableTimesForm::tr("Not available", "Please keep translation short"))
+//#define NO	(ModifyConstraintTeacherNotAvailableTimesForm::tr("Available", "Please keep translation short"))
+#define YES		(QString("X"))
+#define NO		(QString(" "))
 
 ModifyConstraintTeacherNotAvailableTimesForm::ModifyConstraintTeacherNotAvailableTimesForm(ConstraintTeacherNotAvailableTimes* ctr)
 {
+    setupUi(this);
+
+    connect(okPushButton, SIGNAL(clicked()), this /*ModifyConstraintTeacherNotAvailableTimesForm_template*/, SLOT(ok()));
+    connect(cancelPushButton, SIGNAL(clicked()), this /*ModifyConstraintTeacherNotAvailableTimesForm_template*/, SLOT(cancel()));
+    connect(notAllowedTimesTable, SIGNAL(itemClicked(QTableWidgetItem*)), this, SLOT(itemClicked(QTableWidgetItem*)));
+    connect(setAllAvailablePushButton, SIGNAL(clicked()), this /*ModifyConstraintTeacherNotAvailableTimesForm_template*/, SLOT(setAllAvailable()));
+    connect(setAllNotAvailablePushButton, SIGNAL(clicked()), this /*ModifyConstraintTeacherNotAvailableTimesForm_template*/, SLOT(setAllNotAvailable()));
+
+
 	//setWindowFlags(Qt::Window);
 	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
@@ -36,6 +56,9 @@ ModifyConstraintTeacherNotAvailableTimesForm::ModifyConstraintTeacherNotAvailabl
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
 	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+
+	QSize tmp1=teachersComboBox->minimumSizeHint();
+	Q_UNUSED(tmp1);
 	
 	this->_ctr=ctr;
 	
@@ -43,13 +66,17 @@ ModifyConstraintTeacherNotAvailableTimesForm::ModifyConstraintTeacherNotAvailabl
 	
 	updateTeachersComboBox();
 
-	notAllowedTimesTable->setNumRows(gt.rules.nHoursPerDay);
-	notAllowedTimesTable->setNumCols(gt.rules.nDaysPerWeek);
+	notAllowedTimesTable->setRowCount(gt.rules.nHoursPerDay);
+	notAllowedTimesTable->setColumnCount(gt.rules.nDaysPerWeek);
 
-	for(int j=0; j<gt.rules.nDaysPerWeek; j++)
-		notAllowedTimesTable->horizontalHeader()->setLabel(j, gt.rules.daysOfTheWeek[j]);
-	for(int i=0; i<gt.rules.nHoursPerDay; i++)
-		notAllowedTimesTable->verticalHeader()->setLabel(i, gt.rules.hoursOfTheDay[i]);
+	for(int j=0; j<gt.rules.nDaysPerWeek; j++){
+		QTableWidgetItem* item=new QTableWidgetItem(gt.rules.daysOfTheWeek[j]);
+		notAllowedTimesTable->setHorizontalHeaderItem(j, item);
+	}
+	for(int i=0; i<gt.rules.nHoursPerDay; i++){
+		QTableWidgetItem* item=new QTableWidgetItem(gt.rules.hoursOfTheDay[i]);
+		notAllowedTimesTable->setVerticalHeaderItem(i, item);
+	}
 
 	bool currentMatrix[MAX_HOURS_PER_DAY][MAX_DAYS_PER_WEEK];
 	for(int i=0; i<gt.rules.nHoursPerDay; i++)
@@ -65,29 +92,115 @@ ModifyConstraintTeacherNotAvailableTimesForm::ModifyConstraintTeacherNotAvailabl
 	}
 
 	for(int i=0; i<gt.rules.nHoursPerDay; i++)
-		for(int j=0; j<gt.rules.nDaysPerWeek; j++)
+		for(int j=0; j<gt.rules.nDaysPerWeek; j++){
+			QTableWidgetItem* item= new QTableWidgetItem();
+			item->setTextAlignment(Qt::AlignCenter);
+			item->setFlags(Qt::ItemIsSelectable|Qt::ItemIsEnabled);
+			notAllowedTimesTable->setItem(i, j, item);
+
 			if(!currentMatrix[i][j])
-				notAllowedTimesTable->setText(i, j, NO);
+				item->setText(NO);
 			else
-				notAllowedTimesTable->setText(i, j, YES);
+				item->setText(YES);
+				
+			colorItem(item);
+		}
+		
+	notAllowedTimesTable->resizeRowsToContents();
+
+	connect(notAllowedTimesTable->horizontalHeader(), SIGNAL(sectionClicked(int)), this, SLOT(horizontalHeaderClicked(int)));
+	connect(notAllowedTimesTable->verticalHeader(), SIGNAL(sectionClicked(int)), this, SLOT(verticalHeaderClicked(int)));
+	
+	notAllowedTimesTable->setSelectionMode(QAbstractItemView::NoSelection);
+	
+	tableWidgetUpdateBug(notAllowedTimesTable);
 }
 
 ModifyConstraintTeacherNotAvailableTimesForm::~ModifyConstraintTeacherNotAvailableTimesForm()
 {
 }
 
+void ModifyConstraintTeacherNotAvailableTimesForm::colorItem(QTableWidgetItem* item)
+{
+	if(USE_GUI_COLORS){
+		if(item->text()==NO)
+			item->setBackground(QBrush(Qt::darkGreen));
+		else
+			item->setBackground(QBrush(Qt::darkRed));
+		item->setForeground(QBrush(Qt::lightGray));
+	}
+}
+
+void ModifyConstraintTeacherNotAvailableTimesForm::horizontalHeaderClicked(int col)
+{
+	if(col>=0 && col<gt.rules.nDaysPerWeek){
+		QString s=notAllowedTimesTable->item(0, col)->text();
+		if(s==YES)
+			s=NO;
+		else{
+			assert(s==NO);
+			s=YES;
+		}
+
+		for(int row=0; row<gt.rules.nHoursPerDay; row++){
+			/*QString s=notAllowedTimesTable->text(row, col);
+			if(s==YES)
+				s=NO;
+			else{
+				assert(s==NO);
+				s=YES;
+			}*/
+			notAllowedTimesTable->item(row, col)->setText(s);
+			colorItem(notAllowedTimesTable->item(row,col));
+		}
+		tableWidgetUpdateBug(notAllowedTimesTable);
+	}
+}
+
+void ModifyConstraintTeacherNotAvailableTimesForm::verticalHeaderClicked(int row)
+{
+	if(row>=0 && row<gt.rules.nHoursPerDay){
+		QString s=notAllowedTimesTable->item(row, 0)->text();
+		if(s==YES)
+			s=NO;
+		else{
+			assert(s==NO);
+			s=YES;
+		}
+	
+		for(int col=0; col<gt.rules.nDaysPerWeek; col++){
+			/*QString s=notAllowedTimesTable->text(row, col);
+			if(s==YES)
+				s=NO;
+			else{
+				assert(s==NO);
+				s=YES;
+			}*/
+			notAllowedTimesTable->item(row, col)->setText(s);
+			colorItem(notAllowedTimesTable->item(row,col));
+		}
+		tableWidgetUpdateBug(notAllowedTimesTable);
+	}
+}
+
 void ModifyConstraintTeacherNotAvailableTimesForm::setAllAvailable()
 {
 	for(int i=0; i<gt.rules.nHoursPerDay; i++)
-		for(int j=0; j<gt.rules.nDaysPerWeek; j++)
-			notAllowedTimesTable->setText(i, j, NO);
+		for(int j=0; j<gt.rules.nDaysPerWeek; j++){
+			notAllowedTimesTable->item(i, j)->setText(NO);
+			colorItem(notAllowedTimesTable->item(i,j));
+		}
+	tableWidgetUpdateBug(notAllowedTimesTable);
 }
 
 void ModifyConstraintTeacherNotAvailableTimesForm::setAllNotAvailable()
 {
 	for(int i=0; i<gt.rules.nHoursPerDay; i++)
-		for(int j=0; j<gt.rules.nDaysPerWeek; j++)
-			notAllowedTimesTable->setText(i, j, YES);
+		for(int j=0; j<gt.rules.nDaysPerWeek; j++){
+			notAllowedTimesTable->item(i, j)->setText(YES);
+			colorItem(notAllowedTimesTable->item(i,j));
+		}
+	tableWidgetUpdateBug(notAllowedTimesTable);
 }
 
 void ModifyConstraintTeacherNotAvailableTimesForm::updateTeachersComboBox(){
@@ -103,21 +216,19 @@ void ModifyConstraintTeacherNotAvailableTimesForm::updateTeachersComboBox(){
 	teachersComboBox->setCurrentItem(j);
 }
 
-void ModifyConstraintTeacherNotAvailableTimesForm::tableClicked(int row, int col, int button, const QPoint& mousePos)
+void ModifyConstraintTeacherNotAvailableTimesForm::itemClicked(QTableWidgetItem* item)
 {
-	Q_UNUSED(button);
-	Q_UNUSED(mousePos);
-
-	if(row>=0 && row<gt.rules.nHoursPerDay && col>=0 && col<gt.rules.nDaysPerWeek){
-		QString s=notAllowedTimesTable->text(row, col);
-		if(s==YES)
-			s=NO;
-		else{
-			assert(s==NO);
-			s=YES;
-		}
-		notAllowedTimesTable->setText(row, col, s);
+	QString s=item->text();
+	if(s==YES)
+		s=NO;
+	else{
+		assert(s==NO);
+		s=YES;
 	}
+	item->setText(s);
+	colorItem(item);
+
+	tableWidgetUpdateBug(notAllowedTimesTable);
 }
 
 void ModifyConstraintTeacherNotAvailableTimesForm::ok()
@@ -143,8 +254,8 @@ void ModifyConstraintTeacherNotAvailableTimesForm::ok()
 		if(c!=this->_ctr && c->type==CONSTRAINT_TEACHER_NOT_AVAILABLE_TIMES){
 			ConstraintTeacherNotAvailableTimes* cc=(ConstraintTeacherNotAvailableTimes*)c;
 			if(cc->teacher==teacher_name){
-				QMessageBox::warning(this, QObject::tr("FET information"),
-					QObject::tr("A constraint of this type exists for the same teacher - cannot proceed"));
+				QMessageBox::warning(this, tr("FET information"),
+					tr("A constraint of this type exists for the same teacher - cannot proceed"));
 				return;
 			}
 		}																												
@@ -156,7 +267,7 @@ void ModifyConstraintTeacherNotAvailableTimesForm::ok()
 	QList<int> hours;
 	for(int j=0; j<gt.rules.nDaysPerWeek; j++)
 		for(int i=0; i<gt.rules.nHoursPerDay; i++)
-			if(notAllowedTimesTable->text(i, j)==YES){
+			if(notAllowedTimesTable->item(i, j)->text()==YES){
 				days.append(j);
 				hours.append(i);
 			}
