@@ -17,6 +17,8 @@
 
 #include "generate.h"
 
+#include "centerwidgetonscreen.h"
+
 #include "timetablegenerateform.h"
 #include "timetable_defs.h"
 #include "timetable.h"
@@ -30,6 +32,9 @@
 
 #include <QTextEdit>
 
+#include <QDateTime>
+#include <QLocale>
+
 #include <iostream>
 #include <fstream>
 using namespace std;
@@ -38,6 +43,10 @@ using namespace std;
 
 #include <QMutex>
 
+#include <QDir>
+
+#include "longtextmessagebox.h"
+
 QMutex mutex;
 
 static GenerateThread generateThread;
@@ -57,6 +66,8 @@ extern bool rooms_schedule_ready;
 
 extern Solution best_solution;
 
+extern Solution highestStageSolution;
+
 extern QString conflictsString;
 
 
@@ -68,6 +79,10 @@ int initialOrderOfActivitiesIndices[MAX_ACTIVITIES];
 
 extern int maxActivitiesPlaced;
 
+extern QDateTime generationStartDateTime;
+extern QDateTime generationHighestStageDateTime;
+
+QString getActivityDetailedDescription(const Rules& r, int id);
 
 void GenerateThread::run()
 {
@@ -79,6 +94,19 @@ void GenerateThread::run()
 
 TimetableGenerateForm::TimetableGenerateForm()
 {
+    setupUi(this);
+
+    connect(startPushButton, SIGNAL(clicked()), this /*TimetableGenerateForm_template*/, SLOT(start()));
+    connect(stopPushButton, SIGNAL(clicked()), this /*TimetableGenerateForm_template*/, SLOT(stop()));
+    connect(writeResultsPushButton, SIGNAL(clicked()), this /*TimetableGenerateForm_template*/, SLOT(write()));
+    connect(closePushButton, SIGNAL(clicked()), this /*TimetableGenerateForm_template*/, SLOT(closePressed()));
+    connect(helpPushButton, SIGNAL(clicked()), this /*TimetableGenerateForm_template*/, SLOT(help()));
+    connect(seeImpossiblePushButton, SIGNAL(clicked()), this /*TimetableGenerateForm_template*/, SLOT(seeImpossible()));
+    connect(seeInitialOrderPushButton, SIGNAL(clicked()), this /*TimetableGenerateForm_template*/, SLOT(seeInitialOrder()));
+
+    connect(writeHighestStagePushButton, SIGNAL(clicked()), this /*TimetableGenerateForm_template*/, SLOT(writeHighestStage()));
+    connect(stopHighestPushButton, SIGNAL(clicked()), this, SLOT(stopHighest()));
+
 	//setWindowFlags(Qt::Window);
 	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
@@ -89,12 +117,17 @@ TimetableGenerateForm::TimetableGenerateForm()
 	
 	simulation_running=false;
 
+	startPushButton->setDefault(true);
+
 	startPushButton->setEnabled(TRUE);
 	stopPushButton->setDisabled(TRUE);
+	stopHighestPushButton->setDisabled(TRUE);
 	closePushButton->setEnabled(TRUE);
 	writeResultsPushButton->setDisabled(TRUE);
+	writeHighestStagePushButton->setDisabled(TRUE);
 	seeImpossiblePushButton->setDisabled(TRUE);
 	seeInitialOrderPushButton->setDisabled(TRUE);
+	//seeHighestStagePushButton->setDisabled(TRUE);
 
 	connect(&gen, SIGNAL(activityPlaced(int)),
 	 this, SLOT(activityPlaced(int)));
@@ -103,7 +136,7 @@ TimetableGenerateForm::TimetableGenerateForm()
 	connect(&gen, SIGNAL(impossibleToSolve()),
 	 this, SLOT(impossibleToSolve()));
 
-	this->setAttribute(Qt::WA_DeleteOnClose);
+//	this->setAttribute(Qt::WA_DeleteOnClose);
 }
 
 TimetableGenerateForm::~TimetableGenerateForm()
@@ -147,12 +180,19 @@ void TimetableGenerateForm::start(){
 
 	startPushButton->setDisabled(TRUE);
 	stopPushButton->setEnabled(TRUE);
+	stopHighestPushButton->setEnabled(TRUE);
 	closePushButton->setDisabled(TRUE);
 	writeResultsPushButton->setEnabled(TRUE);
+	writeHighestStagePushButton->setEnabled(TRUE);
 	seeImpossiblePushButton->setEnabled(TRUE);
 	seeInitialOrderPushButton->setEnabled(TRUE);
+	//seeHighestStagePushButton->setEnabled(TRUE);
 
 	simulation_running=true;
+	
+	gen.c.makeUnallocated(gt.rules);
+	
+	TimetableExport::writeRandomSeed();
 
 	generateThread.start();
 }
@@ -187,7 +227,8 @@ void TimetableGenerateForm::stop()
 
 	//update the string representing the conflicts
 	conflictsString = "";
-	conflictsString+="Total conflicts: ";
+	conflictsString+=TimetableGenerateForm::tr("Total conflicts:");
+	conflictsString+=" ";
 	conflictsString+=QString::number(c.conflictsTotal);
 	conflictsString+="\n";
 	conflictsString += TimetableGenerateForm::tr("Conflicts listing (in decreasing order):\n");
@@ -201,13 +242,28 @@ void TimetableGenerateForm::stop()
 	 "Maybe you can consider lowering the constraints.");
 
 	s+=" ";
+	
+	QString kk;
+	kk=FILE_SEP;
+	if(INPUT_FILENAME_XML=="")
+		kk.append("unnamed");
+	else{
+		kk.append(INPUT_FILENAME_XML.right(INPUT_FILENAME_XML.length()-INPUT_FILENAME_XML.findRev(FILE_SEP)-1));
+
+		if(kk.right(4)==".fet")
+			kk=kk.left(kk.length()-4);
+		//else if(INPUT_FILENAME_XML!="")
+		//	cout<<"Minor problem - input file does not end in .fet extension - might be a problem when saving the timetables"<<" (file:"<<__FILE__<<", line:"<<__LINE__<<")"<<endl;
+	}
+	kk.append("-single");
 
 	s+=TimetableGenerateForm::tr("The partial results are saved in the directory %1 in html and xml mode"
-	 " and the conflicts in txt mode").arg(QDir::toNativeSeparators(OUTPUT_DIR));
+	 " and the conflicts in txt mode").arg(QDir::toNativeSeparators(OUTPUT_DIR+FILE_SEP+"timetables"+kk));
 
 	s+="\n\n";
 
-	s+=TimetableGenerateForm::tr("Additional information relating impossible to schedule activities:\n\n");
+	s+=TimetableGenerateForm::tr("Additional information relating impossible to schedule activities:");
+	s+="\n\n";
 
 	s+=tr("FET managed to schedule correctly the first %1 most difficult activities."
 	 " You can see initial order of placing the activities in the generate dialog. The activity which might cause problems"
@@ -225,31 +281,9 @@ void TimetableGenerateForm::stop()
 	 && initialOrderOfActivitiesIndices[maxActivitiesPlaced]>=0 && initialOrderOfActivitiesIndices[maxActivitiesPlaced]<gt.rules.nInternalActivities){
 		int ai=initialOrderOfActivitiesIndices[maxActivitiesPlaced];
 
-		s+=TimetableGenerateForm::tr("Id: %1").arg(gt.rules.internalActivitiesList[ai].id);
-		s+=",";
-		s+=TimetableGenerateForm::tr(" TN: ", "Teacher name");
-		bool first=true;
-		foreach(QString tn, gt.rules.internalActivitiesList[ai].teachersNames){
-			if(!first)
-				s+=", ";
-			first=false;
-			s+=tn;
-		}
-		s+=", ";
-		s+=TimetableGenerateForm::tr("SN: %1", "Subject name").arg(gt.rules.internalActivitiesList[ai].subjectName);
-		s+=", ";
-		if(gt.rules.internalActivitiesList[ai].activityTagsNames.count()>0){
-			s+=TimetableGenerateForm::tr("AT: %1", "Activity tags").arg(gt.rules.internalActivitiesList[ai].activityTagsNames.join(","));
-			s+=", ";
-		}
-		first=true;
-		s+=TimetableGenerateForm::tr(" StN: ", "Students names");
-		foreach(QString sn, gt.rules.internalActivitiesList[ai].studentsNames){
-			if(!first)
-				s+=", ";
-			first=false;
-			s+=sn;
-		}
+		s+=TimetableGenerateForm::tr("Id: %1 (%2)", "%1 is id of activity, %2 is detailed description of activity")
+			.arg(gt.rules.internalActivitiesList[ai].id)
+			.arg(getActivityDetailedDescription(gt.rules, gt.rules.internalActivitiesList[ai].id));
 	}
 	else
 		s+=tr("Difficult activity cannot be computed - please report possible bug");
@@ -260,10 +294,12 @@ void TimetableGenerateForm::stop()
 	s+="\n\n";
 
 	s+=TimetableGenerateForm::tr("Please check the constraints related to the last "
-	 "activities in the list below, which might be impossible to schedule:\n\n");
+	 "activities in the list below, which might be impossible to schedule:");
+	s+="\n\n";
 	s+=TimetableGenerateForm::tr("Here are the placed activities which lead to an inconsistency, "
 	 "in order from the first one to the last (the last one FET failed to schedule "
-	 "and the last ones are most likely impossible):\n\n");
+	 "and the last ones are most likely impossible):");
+	s+="\n\n";
 	for(int i=0; i<gen.nDifficultActivities; i++){
 		int ai=gen.difficultActivities[i];
 
@@ -271,31 +307,9 @@ void TimetableGenerateForm::stop()
 
 		s+=", ";
 
-		s+=TimetableGenerateForm::tr("Id: %1").arg(gt.rules.internalActivitiesList[ai].id);
-		s+=",";
-		s+=TimetableGenerateForm::tr(" TN: ");
-		bool first=true;
-		foreach(QString tn, gt.rules.internalActivitiesList[ai].teachersNames){
-			if(!first)
-				s+=", ";
-			first=false;
-			s+=tn;
-		}
-		s+=", ";
-		s+=TimetableGenerateForm::tr("SN: %1").arg(gt.rules.internalActivitiesList[ai].subjectName);
-		s+=", ";
-		if(gt.rules.internalActivitiesList[ai].activityTagsNames.count()>0){
-			s+=TimetableGenerateForm::tr("AT: %1", "Activity tags").arg(gt.rules.internalActivitiesList[ai].activityTagsNames.join(","));
-			s+=", ";
-		}
-		first=true;
-		s+=TimetableGenerateForm::tr(" StN: ");
-		foreach(QString sn, gt.rules.internalActivitiesList[ai].studentsNames){
-			if(!first)
-				s+=", ";
-			first=false;
-			s+=sn;
-		}
+		s+=TimetableGenerateForm::tr("Id: %1 (%2)", "%1 is id of activity, %2 is detailed description of activity")
+			.arg(gt.rules.internalActivitiesList[ai].id)
+			.arg(getActivityDetailedDescription(gt.rules, gt.rules.internalActivitiesList[ai].id));
 
 		s+="\n";
 	}
@@ -303,9 +317,11 @@ void TimetableGenerateForm::stop()
 	mutex.unlock();
 
 	//show the message in a dialog
-	QDialog* dialog=new QDialog();
+	QDialog dialog;
+	
+	dialog.setWindowTitle(TimetableGenerateForm::tr("Generation stopped", "The title of a dialog, meaning that the generation of the timetable was stopped."));
 
-	QVBoxLayout* vl=new QVBoxLayout(dialog);
+	QVBoxLayout* vl=new QVBoxLayout(&dialog);
 	QTextEdit* te=new QTextEdit();
 	te->setPlainText(s);
 	te->setReadOnly(true);
@@ -317,22 +333,163 @@ void TimetableGenerateForm::stop()
 
 	vl->addWidget(te);
 	vl->addLayout(hl);
-	connect(pb, SIGNAL(clicked()), dialog, SLOT(close()));
+	connect(pb, SIGNAL(clicked()), &dialog, SLOT(close()));
 
-	dialog->setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QRect rect = QApplication::desktop()->availableGeometry(dialog);
-	//QDesktopWidget* desktop=QApplication::desktop();
+	/*dialog.setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QRect rect = QApplication::desktop()->availableGeometry(&dialog);
 	int xx=rect.width()/2 - 350;
 	int yy=rect.height()/2 - 250;
-	dialog->setGeometry(xx, yy, 700, 500);
+	dialog.setGeometry(xx, yy, 700, 500);*/
+	dialog.setGeometry(0,0,700,500);
+	centerWidgetOnScreen(&dialog);
 	
-	dialog->exec();
+	dialog.exec();
 
 	startPushButton->setEnabled(TRUE);
 	stopPushButton->setDisabled(TRUE);
+	stopHighestPushButton->setDisabled(TRUE);
 	closePushButton->setEnabled(TRUE);
 	writeResultsPushButton->setDisabled(TRUE);
+	writeHighestStagePushButton->setDisabled(TRUE);
 	seeImpossiblePushButton->setDisabled(TRUE);
+	//seeHighestStagePushButton->setDisabled(TRUE);
+}
+
+void TimetableGenerateForm::stopHighest()
+{
+	if(!simulation_running){
+		/*QMessageBox::critical(this, TimetableGenerateForm::tr("FET information"),
+		 TimetableGenerateForm::tr("Simulation stopped but the simulation is not running."
+		 " This should not happen. Maybe you aborted simulation previously. Please report possible bug to author"));*/
+
+		return;
+	}
+
+	simulation_running=false;
+
+	mutex.lock();
+	gen.abortOptimization=true;
+	mutex.unlock();
+
+	mutex.lock();
+
+	Solution& c=highestStageSolution;
+
+	//needed to find the conflicts strings
+	QString tmp;
+	c.fitness(gt.rules, &tmp);
+
+	TimetableExport::getStudentsTimetable(c);
+	TimetableExport::getTeachersTimetable(c);
+	TimetableExport::getRoomsTimetable(c);
+
+	//update the string representing the conflicts
+	conflictsString = "";
+	conflictsString+=TimetableGenerateForm::tr("Total conflicts:");
+	conflictsString+=" ";
+	conflictsString+=QString::number(c.conflictsTotal);
+	conflictsString+="\n";
+	conflictsString += TimetableGenerateForm::tr("Conflicts listing (in decreasing order):\n");
+
+	foreach(QString t, c.conflictsDescriptionList)
+		conflictsString+=t+"\n";
+
+	TimetableExport::writeHighestStageResults();
+
+	QString s=TimetableGenerateForm::tr("Simulation interrupted. FET could not find a perfect timetable. "
+	 "Maybe you can consider lowering the constraints.");
+
+	s+=" ";
+	
+	QString kk;
+	kk=FILE_SEP;
+	if(INPUT_FILENAME_XML=="")
+		kk.append("unnamed");
+	else{
+		kk.append(INPUT_FILENAME_XML.right(INPUT_FILENAME_XML.length()-INPUT_FILENAME_XML.findRev(FILE_SEP)-1));
+
+		if(kk.right(4)==".fet")
+			kk=kk.left(kk.length()-4);
+		//else if(INPUT_FILENAME_XML!="")
+		//	cout<<"Minor problem - input file does not end in .fet extension - might be a problem when saving the timetables"<<" (file:"<<__FILE__<<", line:"<<__LINE__<<")"<<endl;
+	}
+	kk.append("-highest");
+
+	s+=TimetableGenerateForm::tr("The partial highest stage results are saved in the directory %1 in html and xml mode"
+	 " and the conflicts in txt mode").arg(QDir::toNativeSeparators(OUTPUT_DIR+FILE_SEP+"timetables"+kk));
+
+	s+="\n\n";
+
+	s+=TimetableGenerateForm::tr("Additional information relating impossible to schedule activities:");
+	s+="\n\n";
+
+	s+=tr("FET managed to schedule correctly the first %1 most difficult activities."
+	 " You can see initial order of placing the activities in the generate dialog. The activity which might cause problems"
+	 " might be the next activity in the initial order of evaluation. This activity is listed below:")
+	 .arg(maxActivitiesPlaced);
+	 
+	s+="\n\n";
+	
+	s+=tr("Please check constraints related to following possibly problematic activity (or teacher(s), or students set(s)):");
+	s+="\n";
+	s+="-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- ";
+	s+="\n";
+	
+	if(maxActivitiesPlaced>=0 && maxActivitiesPlaced<gt.rules.nInternalActivities 
+	 && initialOrderOfActivitiesIndices[maxActivitiesPlaced]>=0 && initialOrderOfActivitiesIndices[maxActivitiesPlaced]<gt.rules.nInternalActivities){
+		int ai=initialOrderOfActivitiesIndices[maxActivitiesPlaced];
+
+		s+=TimetableGenerateForm::tr("Id: %1 (%2)", "%1 is id of activity, %2 is detailed description of activity")
+			.arg(gt.rules.internalActivitiesList[ai].id)
+			.arg(getActivityDetailedDescription(gt.rules, gt.rules.internalActivitiesList[ai].id));
+	}
+	else
+		s+=tr("Difficult activity cannot be computed - please report possible bug");
+
+	s+="\n";
+
+	mutex.unlock();
+
+	//show the message in a dialog
+	QDialog dialog;
+
+	dialog.setWindowTitle(TimetableGenerateForm::tr("Generation stopped (highest stage)", "The title of a dialog, meaning that the generation of the timetable was stopped "
+		"and highest stage timetable written."));
+
+	QVBoxLayout* vl=new QVBoxLayout(&dialog);
+	QTextEdit* te=new QTextEdit();
+	te->setPlainText(s);
+	te->setReadOnly(true);
+	QPushButton* pb=new QPushButton(TimetableGenerateForm::tr("OK"));
+
+	QHBoxLayout* hl=new QHBoxLayout(0);
+	hl->addStretch(1);
+	hl->addWidget(pb);
+
+	vl->addWidget(te);
+	vl->addLayout(hl);
+	connect(pb, SIGNAL(clicked()), &dialog, SLOT(close()));
+
+	/*
+	dialog.setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QRect rect = QApplication::desktop()->availableGeometry(&dialog);
+	int xx=rect.width()/2 - 350;
+	int yy=rect.height()/2 - 250;
+	dialog.setGeometry(xx, yy, 700, 500);
+	*/
+	dialog.setGeometry(0,0,700,500);
+	centerWidgetOnScreen(&dialog);
+	
+	dialog.exec();
+
+	startPushButton->setEnabled(TRUE);
+	stopPushButton->setDisabled(TRUE);
+	stopHighestPushButton->setDisabled(TRUE);
+	closePushButton->setEnabled(TRUE);
+	writeResultsPushButton->setDisabled(TRUE);
+	writeHighestStagePushButton->setDisabled(TRUE);
+	seeImpossiblePushButton->setDisabled(TRUE);
+	//seeHighestStagePushButton->setDisabled(TRUE);
 }
 
 void TimetableGenerateForm::impossibleToSolve()
@@ -367,7 +524,8 @@ void TimetableGenerateForm::impossibleToSolve()
 
 	//update the string representing the conflicts
 	conflictsString = "";
-	conflictsString+="Total conflicts: ";
+	conflictsString+=TimetableGenerateForm::tr("Total conflicts:");
+	conflictsString+=" ";
 	conflictsString+=QString::number(c.conflictsTotal);
 	conflictsString+="\n";
 	conflictsString += TimetableGenerateForm::tr("Conflicts listing (in decreasing order):\n");
@@ -383,14 +541,30 @@ void TimetableGenerateForm::impossibleToSolve()
 
 	s+=" ";
 
+	QString kk;
+	kk=FILE_SEP;
+	if(INPUT_FILENAME_XML=="")
+		kk.append("unnamed");
+	else{
+		kk.append(INPUT_FILENAME_XML.right(INPUT_FILENAME_XML.length()-INPUT_FILENAME_XML.findRev(FILE_SEP)-1));
+
+		if(kk.right(4)==".fet")
+			kk=kk.left(kk.length()-4);
+		//else if(INPUT_FILENAME_XML!="")
+			//cout<<"Minor problem - input file does not end in .fet extension - might be a problem when saving the timetables"<<" (file:"<<__FILE__<<", line:"<<__LINE__<<")"<<endl;
+	}
+	kk.append("-single");
+
 	s+=TimetableGenerateForm::tr("The partial results are saved in the directory %1 in html and xml mode"
-	 " and the conflicts in txt mode").arg(QDir::toNativeSeparators(OUTPUT_DIR));
+	 " and the conflicts in txt mode").arg(QDir::toNativeSeparators(OUTPUT_DIR+FILE_SEP+"timetables"+kk));
 
 	s+="\n\n";
 
-	s+=TimetableGenerateForm::tr("Additional information relating impossible to schedule activities:\n\n");
+	s+=TimetableGenerateForm::tr("Additional information relating impossible to schedule activities:");
+	s+="\n\n";
 	s+=TimetableGenerateForm::tr("Please check the constraints related to the "
-	 "activity below, which might be impossible to schedule:\n\n");
+	 "activity below, which might be impossible to schedule:");
+	s+="\n\n";
 	for(int i=0; i<gen.nDifficultActivities; i++){
 		int ai=gen.difficultActivities[i];
 
@@ -398,30 +572,9 @@ void TimetableGenerateForm::impossibleToSolve()
 
 		s+=", ";
 
-		s+=TimetableGenerateForm::tr("Id: %1").arg(gt.rules.internalActivitiesList[ai].id);
-		s+=TimetableGenerateForm::tr(" TN: ");
-		bool first=true;
-		foreach(QString tn, gt.rules.internalActivitiesList[ai].teachersNames){
-			if(!first)
-				s+=", ";
-			first=false;
-			s+=tn;
-		}
-		s+=", ";
-		s+=TimetableGenerateForm::tr("SN: %1").arg(gt.rules.internalActivitiesList[ai].subjectName);
-		s+=", ";
-		if(gt.rules.internalActivitiesList[ai].activityTagsNames.count()>0){
-			s+=TimetableGenerateForm::tr("AT: %1", "Activity tags").arg(gt.rules.internalActivitiesList[ai].activityTagsNames.join(","));
-			s+=", ";
-		}
-		first=true;
-		s+=TimetableGenerateForm::tr(" StN: ");
-		foreach(QString sn, gt.rules.internalActivitiesList[ai].studentsNames){
-			if(!first)
-				s+=", ";
-			first=false;
-			s+=sn;
-		}
+		s+=TimetableGenerateForm::tr("Id: %1 (%2)", "%1 is id of activity, %2 is detailed description of activity")
+			.arg(gt.rules.internalActivitiesList[ai].id)
+			.arg(getActivityDetailedDescription(gt.rules, gt.rules.internalActivitiesList[ai].id));
 
 		s+="\n";
 	}
@@ -429,9 +582,11 @@ void TimetableGenerateForm::impossibleToSolve()
 	mutex.unlock();
 
 	//show the message in a dialog
-	QDialog* dialog=new QDialog();
+	QDialog dialog;
 
-	QVBoxLayout* vl=new QVBoxLayout(dialog);
+	dialog.setWindowTitle(TimetableGenerateForm::tr("Generation impossible", "The title of a dialog, meaning that the generation of the timetable is impossible."));
+
+	QVBoxLayout* vl=new QVBoxLayout(&dialog);
 	QTextEdit* te=new QTextEdit();
 	te->setPlainText(s);
 	te->setReadOnly(true);
@@ -443,22 +598,26 @@ void TimetableGenerateForm::impossibleToSolve()
 
 	vl->addWidget(te);
 	vl->addLayout(hl);
-	connect(pb, SIGNAL(clicked()), dialog, SLOT(close()));
+	connect(pb, SIGNAL(clicked()), &dialog, SLOT(close()));
 
-	dialog->setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QRect rect = QApplication::desktop()->availableGeometry(dialog);
-	//QDesktopWidget* desktop=QApplication::desktop();
+	/*dialog.setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QRect rect = QApplication::desktop()->availableGeometry(&dialog);
 	int xx=rect.width()/2 - 350;
 	int yy=rect.height()/2 - 250;
-	dialog->setGeometry(xx, yy, 700, 500);
+	dialog.setGeometry(xx, yy, 700, 500);*/
+	dialog.setGeometry(0,0,700,500);
+	centerWidgetOnScreen(&dialog);
 
-	dialog->exec();
+	dialog.exec();
 
 	startPushButton->setEnabled(TRUE);
 	stopPushButton->setDisabled(TRUE);
+	stopHighestPushButton->setDisabled(TRUE);
 	closePushButton->setEnabled(TRUE);
 	writeResultsPushButton->setDisabled(TRUE);
+	writeHighestStagePushButton->setDisabled(TRUE);
 	seeImpossiblePushButton->setDisabled(TRUE);
+	//seeHighestStagePushButton->setDisabled(TRUE);
 }
 
 void TimetableGenerateForm::simulationFinished()
@@ -489,7 +648,8 @@ void TimetableGenerateForm::simulationFinished()
 
 	//update the string representing the conflicts
 	conflictsString = "";
-	conflictsString+=tr("Total soft conflicts: ");
+	conflictsString+=tr("Total soft conflicts:");
+	conflictsString+=" ";
 	conflictsString+=QString::number(c.conflictsTotal);
 	conflictsString+="\n";
 	conflictsString += TimetableGenerateForm::tr("Soft conflicts listing (in decreasing order):\n");
@@ -501,6 +661,20 @@ void TimetableGenerateForm::simulationFinished()
 
 	//mutex.unlock();
 
+	QString kk;
+	kk=FILE_SEP;
+	if(INPUT_FILENAME_XML=="")
+		kk.append("unnamed");
+	else{
+		kk.append(INPUT_FILENAME_XML.right(INPUT_FILENAME_XML.length()-INPUT_FILENAME_XML.findRev(FILE_SEP)-1));
+
+		if(kk.right(4)==".fet")
+			kk=kk.left(kk.length()-4);
+		//else if(INPUT_FILENAME_XML!="")
+			//cout<<"Minor problem - input file does not end in .fet extension - might be a problem when saving the timetables"<<" (file:"<<__FILE__<<", line:"<<__LINE__<<")"<<endl;
+	}
+	kk.append("-single");
+
 	QMessageBox::information(this, TimetableGenerateForm::tr("FET information"),
 		TimetableGenerateForm::tr("Allocation terminated successfully, remaining %1 weighted"
 		" soft conflicts from constraints with weight percentage lower than 100%"
@@ -508,38 +682,76 @@ void TimetableGenerateForm::simulationFinished()
 		" the output directory for details)."
 		"\n\nSimulation results should be now written. You may check now Timetable/View."
 		" The results are also saved in the directory %2 in"
-		" html and xml mode and the soft conflicts in txt mode").arg(c.conflictsTotal).arg(QDir::toNativeSeparators(OUTPUT_DIR)));
+		" html and xml mode and the soft conflicts in txt mode").arg(c.conflictsTotal).arg(QDir::toNativeSeparators(OUTPUT_DIR+FILE_SEP+"timetables"+kk))
+		+". "+tr("Data+timetable is saved as a .fet data file (with activities locked by constraints)"
+		", so that you can open/modify/regenerate the current timetable later"));
 
 	startPushButton->setEnabled(TRUE);
 	stopPushButton->setDisabled(TRUE);
+	stopHighestPushButton->setDisabled(TRUE);
 	closePushButton->setEnabled(TRUE);
-	writeResultsPushButton->setEnabled(TRUE);
+	writeResultsPushButton->setDisabled(TRUE);
+	writeHighestStagePushButton->setDisabled(TRUE);
 	seeImpossiblePushButton->setDisabled(TRUE);
+	//seeHighestStagePushButton->setDisabled(TRUE);
 }
 
 void TimetableGenerateForm::activityPlaced(int na){
 	assert(gt.rules.initialized && gt.rules.internalStructureComputed);
 
 	mutex.lock();
+	int t=gen.searchTime; //seconds
+	int mact=maxActivitiesPlaced;
+	int secs=gen.timeToHighestStage;
+	mutex.unlock();
 
 	//write to the Qt interface
 	QString s;
 	s+=TimetableGenerateForm::tr("%1 out of %2 activities placed").arg(na).arg(gt.rules.nInternalActivities)+"\n";
 
 	s+=TimetableGenerateForm::tr("Elapsed time:");
-	int t=gen.searchTime; //seconds
 	int h=t/3600;
-	if(h>0)
-		s+=TimetableGenerateForm::tr(" %1 h").arg(h);
+	if(h>0){
+		s+=" ";
+		s+=TimetableGenerateForm::tr("%1 h", "hours").arg(h);
+	}
 	t=t%3600;
 	int m=t/60;
-	if(m>0)
-		s+=TimetableGenerateForm::tr(" %1 m").arg(m);
+	if(m>0){
+		s+=" ";
+		s+=TimetableGenerateForm::tr("%1 m", "minutes").arg(m);
+	}
 	t=t%60;
-	if(t>0)
-		s+=TimetableGenerateForm::tr(" %1 s").arg(t);
+	if(t>0){
+		s+=" ";
+		s+=TimetableGenerateForm::tr("%1 s", "seconds").arg(t);
+	}
+	
+	bool zero=false;
+	if(secs==0)
+		zero=true;
+	int hh=secs/3600;
+	secs%=3600;
+	int mm=secs/60;
+	secs%=60;
+	int ss=secs;
 
-	mutex.unlock();
+	QString tim;
+	if(hh>0){
+		tim+=" ";
+		tim+=tr("%1 h", "hours").arg(hh);
+	}
+	if(mm>0){
+		tim+=" ";
+		tim+=tr("%1 m", "minutes").arg(mm);
+	}
+	if(ss>0 || zero){
+		tim+=" ";
+		tim+=tr("%1 s", "seconds").arg(ss);
+	}
+	tim.remove(0, 1);
+	s+="\n\n";
+	s+=tr("Max placed activities: %1 (at %2)", "%1 represents the maximum number of activities placed, %2 is a time interval").arg(mact).arg(tim);
 
 	currentResultsTextEdit->setText(s);
 
@@ -548,7 +760,7 @@ void TimetableGenerateForm::activityPlaced(int na){
 
 void TimetableGenerateForm::help()
 {
-	QString s="";
+	QString s;
 	
 	s+=TimetableGenerateForm::tr("Please wait. It might take 5 to 20 minutes or even more for very difficult timetables")+"\n";
 	s+=TimetableGenerateForm::tr("Activities are placed in order, most difficult ones first"); s+="\n";
@@ -560,14 +772,14 @@ void TimetableGenerateForm::help()
 	 " and restarting might produce a very fast solution.");
 	s+="\n";
 	s+=TimetableGenerateForm::tr("It is recommended to strengthen the constraints step by step (for"
-	 " instance min n days between activities weight or teacher(s) max gaps), as you obtain feasible timetables.");
+	 " instance min days between activities weight or teacher(s) max gaps), as you obtain feasible timetables.");
 	s+="\n";
 	s+="\n";
 	s+=TimetableGenerateForm::tr("NEW: If your timetable gets stuck on a certain activity number k (and then"
 	 " begins going back), please check the initial evaluation order and see activity number k+1 in this list. I found"
 	 " errors this way.");
 	 
-	QMessageBox::information(this, tr("FET help"), s);
+	LongTextMessageBox::largeInformation(this, tr("FET help"), s);
 }
 
 void TimetableGenerateForm::write(){
@@ -585,7 +797,8 @@ void TimetableGenerateForm::write(){
 
 	//update the string representing the conflicts
 	conflictsString = "";
-	conflictsString+="Total conflicts: ";
+	conflictsString+=TimetableGenerateForm::tr("Total conflicts:");
+	conflictsString+=" ";
 	conflictsString+=QString::number(c.conflictsTotal);
 	conflictsString+="\n";
 	conflictsString += TimetableGenerateForm::tr("Conflicts listing (in decreasing order):\n");
@@ -597,9 +810,70 @@ void TimetableGenerateForm::write(){
 
 	mutex.unlock();
 
+	QString kk;
+	kk=FILE_SEP;
+	if(INPUT_FILENAME_XML=="")
+		kk.append("unnamed");
+	else{
+		kk.append(INPUT_FILENAME_XML.right(INPUT_FILENAME_XML.length()-INPUT_FILENAME_XML.findRev(FILE_SEP)-1));
+
+		if(kk.right(4)==".fet")
+			kk=kk.left(kk.length()-4);
+		//else if(INPUT_FILENAME_XML!="")
+			//cout<<"Minor problem - input file does not end in .fet extension - might be a problem when saving the timetables"<<" (file:"<<__FILE__<<", line:"<<__LINE__<<")"<<endl;
+	}
+	kk.append("-single");
+
 	QMessageBox::information(this, TimetableGenerateForm::tr("FET information"),
 		TimetableGenerateForm::tr("Simulation results should now be written in the directory %1 in html and xml mode"
-		" and the conflicts in txt mode").arg(QDir::toNativeSeparators(OUTPUT_DIR)));
+		" and the conflicts in txt mode").arg(QDir::toNativeSeparators(OUTPUT_DIR+FILE_SEP+"timetables"+kk)));
+}
+
+void TimetableGenerateForm::writeHighestStage(){
+	mutex.lock();
+
+	Solution& c=highestStageSolution;
+
+	//needed to find the conflicts strings
+	QString tmp;
+	c.fitness(gt.rules, &tmp);
+
+	TimetableExport::getStudentsTimetable(c);
+	TimetableExport::getTeachersTimetable(c);
+	TimetableExport::getRoomsTimetable(c);
+
+	//update the string representing the conflicts
+	conflictsString = "";
+	conflictsString+=TimetableGenerateForm::tr("Total conflicts:");
+	conflictsString+=" ";
+	conflictsString+=QString::number(c.conflictsTotal);
+	conflictsString+="\n";
+	conflictsString += TimetableGenerateForm::tr("Conflicts listing (in decreasing order):\n");
+
+	foreach(QString t, c.conflictsDescriptionList)
+		conflictsString+=t+"\n";
+
+	TimetableExport::writeHighestStageResults();
+
+	mutex.unlock();
+
+	QString kk;
+	kk=FILE_SEP;
+	if(INPUT_FILENAME_XML=="")
+		kk.append("unnamed");
+	else{
+		kk.append(INPUT_FILENAME_XML.right(INPUT_FILENAME_XML.length()-INPUT_FILENAME_XML.findRev(FILE_SEP)-1));
+
+		if(kk.right(4)==".fet")
+			kk=kk.left(kk.length()-4);
+		//else if(INPUT_FILENAME_XML!="")
+			//cout<<"Minor problem - input file does not end in .fet extension - might be a problem when saving the timetables"<<" (file:"<<__FILE__<<", line:"<<__LINE__<<")"<<endl;
+	}
+	kk.append("-highest");
+
+	QMessageBox::information(this, TimetableGenerateForm::tr("FET information"),
+		TimetableGenerateForm::tr("Highest stage results should now be written in the directory %1 in html and xml mode"
+		" and the conflicts in txt mode").arg(QDir::toNativeSeparators(OUTPUT_DIR+FILE_SEP+"timetables"+kk)));
 }
 
 void TimetableGenerateForm::closePressed()
@@ -614,12 +888,15 @@ void TimetableGenerateForm::seeImpossible()
 
 	mutex.lock();
 
-	s+=TimetableGenerateForm::tr("Information relating difficult to schedule activities:\n\n");
+	s+=TimetableGenerateForm::tr("Information relating difficult to schedule activities:");
+	s+="\n\n";
 	s+=TimetableGenerateForm::tr("Please check the constraints related to the last "
-	 "activities in the list below, which might be difficult to schedule:\n\n");
+	 "activities in the list below, which might be difficult to schedule:");
+	s+="\n\n";
 	s+=TimetableGenerateForm::tr("Here are the placed activities which lead to a difficulty, "
 	 "in order from the first one to the last (the last one FET failed to schedule "
-	 "and the last ones are difficult):\n\n");
+	 "and the last ones are difficult):");
+	s+="\n\n";
 	for(int i=0; i<gen.nDifficultActivities; i++){
 		int ai=gen.difficultActivities[i];
 
@@ -627,31 +904,9 @@ void TimetableGenerateForm::seeImpossible()
 
 		s+=", ";
 
-		s+=TimetableGenerateForm::tr("Id: %1").arg(gt.rules.internalActivitiesList[ai].id);
-		s+=",";
-		s+=TimetableGenerateForm::tr(" TN: ", "Teacher name");
-		bool first=true;
-		foreach(QString tn, gt.rules.internalActivitiesList[ai].teachersNames){
-			if(!first)
-				s+=", ";
-			first=false;
-			s+=tn;
-		}
-		s+=", ";
-		s+=TimetableGenerateForm::tr("SN: %1", "Subject name").arg(gt.rules.internalActivitiesList[ai].subjectName);
-		s+=", ";
-		if(gt.rules.internalActivitiesList[ai].activityTagsNames.count()>0){
-			s+=TimetableGenerateForm::tr("AT: %1", "Activity tags").arg(gt.rules.internalActivitiesList[ai].activityTagsNames.join(","));
-			s+=", ";
-		}
-		first=true;
-		s+=TimetableGenerateForm::tr(" StN: ", "Students names");
-		foreach(QString sn, gt.rules.internalActivitiesList[ai].studentsNames){
-			if(!first)
-				s+=", ";
-			first=false;
-			s+=sn;
-		}
+		s+=TimetableGenerateForm::tr("Id: %1 (%2)", "%1 is id of activity, %2 is detailed description of activity")
+			.arg(gt.rules.internalActivitiesList[ai].id)
+			.arg(getActivityDetailedDescription(gt.rules, gt.rules.internalActivitiesList[ai].id));
 
 		s+="\n";
 	}
@@ -659,11 +914,11 @@ void TimetableGenerateForm::seeImpossible()
 	mutex.unlock();
 	
 	//show the message in a dialog
-	QDialog* dialog=new QDialog();
+	QDialog dialog;
 	
-	dialog->setWindowTitle(tr("FET - information about difficult activities"));
+	dialog.setWindowTitle(tr("FET - information about difficult activities"));
 
-	QVBoxLayout* vl=new QVBoxLayout(dialog);
+	QVBoxLayout* vl=new QVBoxLayout(&dialog);
 	QTextEdit* te=new QTextEdit();
 	te->setPlainText(s);
 	te->setReadOnly(true);
@@ -675,16 +930,17 @@ void TimetableGenerateForm::seeImpossible()
 
 	vl->addWidget(te);
 	vl->addLayout(hl);
-	connect(pb, SIGNAL(clicked()), dialog, SLOT(close()));
+	connect(pb, SIGNAL(clicked()), &dialog, SLOT(close()));
 
-	dialog->setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QRect rect = QApplication::desktop()->availableGeometry(dialog);
-	//QDesktopWidget* desktop=QApplication::desktop();
+	/*dialog.setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QRect rect = QApplication::desktop()->availableGeometry(&dialog);
 	int xx=rect.width()/2 - 350;
 	int yy=rect.height()/2 - 250;
-	dialog->setGeometry(xx, yy, 700, 500);
+	dialog.setGeometry(xx, yy, 700, 500);*/
+	dialog.setGeometry(0,0,700,500);
+	centerWidgetOnScreen(&dialog);
 
-	dialog->exec();
+	dialog.exec();
 }
 
 void TimetableGenerateForm::seeInitialOrder()
@@ -692,11 +948,11 @@ void TimetableGenerateForm::seeInitialOrder()
 	QString s=initialOrderOfActivities;
 
 	//show the message in a dialog
-	QDialog* dialog=new QDialog();
+	QDialog dialog;
 	
-	dialog->setWindowTitle(tr("FET - information about initial order of evaluation of activities"));
+	dialog.setWindowTitle(tr("FET - information about initial order of evaluation of activities"));
 
-	QVBoxLayout* vl=new QVBoxLayout(dialog);
+	QVBoxLayout* vl=new QVBoxLayout(&dialog);
 	QTextEdit* te=new QTextEdit();
 	te->setPlainText(s);
 	te->setReadOnly(true);
@@ -708,14 +964,17 @@ void TimetableGenerateForm::seeInitialOrder()
 
 	vl->addWidget(te);
 	vl->addLayout(hl);
-	connect(pb, SIGNAL(clicked()), dialog, SLOT(close()));
+	connect(pb, SIGNAL(clicked()), &dialog, SLOT(close()));
 
-	dialog->setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	//QDesktopWidget* desktop=QApplication::desktop();
-	QRect rect = QApplication::desktop()->availableGeometry(dialog);
+	/*
+	dialog.setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QRect rect = QApplication::desktop()->availableGeometry(&dialog);
 	int xx=rect.width()/2 - 350;
 	int yy=rect.height()/2 - 250;
-	dialog->setGeometry(xx, yy, 700, 500);
+	dialog.setGeometry(xx, yy, 700, 500);*/
+	dialog.setGeometry(0,0,700,500);
+	centerWidgetOnScreen(&dialog);
 
-	dialog->exec();
+	dialog.exec();
 }
+
