@@ -18,26 +18,39 @@
 #ifndef TIMETABLEVIEWSTUDENTSFORM_H
 #define TIMETABLEVIEWSTUDENTSFORM_H
 
-#include "timetableviewstudentsform_template.h"
+#include <QResizeEvent>
 
-class TimetableViewStudentsForm : public TimetableViewStudentsForm_template  {
+#include "ui_timetableviewstudentsform_template.h"
+
+class TimetableViewStudentsForm : public QDialog, Ui::TimetableViewStudentsForm_template  {
 	Q_OBJECT
+
+	//bool columnResizeModeInitialized;
+
 public: 
 	TimetableViewStudentsForm();
 	~TimetableViewStudentsForm();
 
-	void yearChanged(const QString& yearName);
-	void groupChanged(const QString& groupName);
-	void subgroupChanged(const QString& subgroupName);
+	void lock(bool lockTime, bool lockSpace);
+	
+	void resizeRowsAfterShow();
 
-	void detailActivity(int row, int col);
-
-	void lock(bool lockTime, bool lockSpace);	
 public slots:
 	void lockTime();
 	void lockSpace();
 	void lockTimeSpace();
 	void updateStudentsTimetableTable();
+
+	void yearChanged(const QString& yearName);
+	void groupChanged(const QString& groupName);
+	void subgroupChanged(const QString& subgroupName);
+
+	void detailActivity(QTableWidgetItem* item);
+	
+	void help();
+
+protected:
+	void resizeEvent(QResizeEvent* event);
 };
 
 #endif
